/*
 * %CopyrightBegin%
 *
 * Copyright Ericsson AB 2005-2012. All Rights Reserved.
 *
 * The contents of this file are subject to the Erlang Public License,
 * Version 1.1, (the "License"); you may not use this file except in
 * compliance with the License. You should have received a copy of the
 * Erlang Public License along with this software. If not, it can be
 * retrieved online at http://www.erlang.org/.
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * %CopyrightEnd%
 */


/*
 * %CopyrightBegin%
 *
 * Copyright Ericsson AB 2005-2011. All Rights Reserved.
 *
 * The contents of this file are subject to the Erlang Public License,
 * Version 1.1, (the "License"); you may not use this file except in
 * compliance with the License. You should have received a copy of the
 * Erlang Public License along with this software. If not, it can be
 * retrieved online at http://www.erlang.org/.
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * %CopyrightEnd%
 */


#ifndef HIPE_ARM_ASM_H
#define HIPE_ARM_ASM_H

/*
 * Tunables.
 */

#define ARM_LEAF_WORDS	16

/*
 * Reserved registers.
 */
#define P	r11
#define NSP	r10
#define HP	r9
#define TEMP_LR	r8

/*
 * Context switching macros.
 *
 * RESTORE_CONTEXT and RESTORE_CONTEXT_QUICK do not affect
 * the condition register.
 */
#define SAVE_CONTEXT_QUICK	\
	mov	TEMP_LR, lr

#define RESTORE_CONTEXT_QUICK	\
	mov	lr, TEMP_LR

#define SAVE_CACHED_STATE	\
	str	HP, [P, #P_HP];	\
	str	NSP, [P, #P_NSP]

#define RESTORE_CACHED_STATE	\
	ldr	HP, [P, #P_HP];	\
	ldr	NSP, [P, #P_NSP]

#define SAVE_CONTEXT_BIF	\
	mov	TEMP_LR, lr;	\
	str	HP, [P, #P_HP]

#define RESTORE_CONTEXT_BIF	\
	ldr	HP, [P, #P_HP]

#define SAVE_CONTEXT_GC	\
	mov	TEMP_LR, lr;	\
	str	lr, [P, #P_NRA];	\
	str	NSP, [P, #P_NSP];	\
	str	HP, [P, #P_HP]

#define RESTORE_CONTEXT_GC	\
	ldr	HP, [P, #P_HP]

/*
 * Argument (parameter) registers.
 */
#define ARM_NR_ARG_REGS	3
#define NR_ARG_REGS	3


#define ARG0	r1
#define ARG1	r2
#define ARG2	r3

/*
 * TEMP_ARG0:
 *	Used in nbif_stack_trap_ra to preserve the return value.
 *	Must be a C callee-save register.
 *	Must be otherwise unused in the return path.
 *
 * TEMP_ARG0:
 *	Used in hipe_arm_inc_stack to preserve the return address
 *	(TEMP_LR contains the caller's saved return address).
 *	Must be a C callee-save register.
 *	Must be otherwise unused in the call path.
 */
#define TEMP_ARG0	r7


#define LOAD_ARG_REGS	ldr r1, [P, #P_ARG0] ; ldr r2, [P, #P_ARG1] ; ldr r3, [P, #P_ARG2] ; 

#define STORE_ARG_REGS	str r1, [P, #P_ARG0] ; str r2, [P, #P_ARG1] ; str r3, [P, #P_ARG2] ; 


/* #define NBIF_ARG_1_0	# mov	r1, r1 */
/* #define NBIF_ARG_2_0	# mov	r1, r1 */
/* #define NBIF_ARG_2_1	# mov	r2, r2 */
/* #define NBIF_ARG_3_0	# mov	r1, r1 */
/* #define NBIF_ARG_3_1	# mov	r2, r2 */
/* #define NBIF_ARG_3_2	# mov	r3, r3 */
/* #define NBIF_ARG_5_0	# mov	r1, r1 */
/* #define NBIF_ARG_5_1	# mov	r2, r2 */
/* #define NBIF_ARG_5_2	# mov	r3, r3 */
/* #define NBIF_ARG_5_3	ldr	r4, [NSP, #4] */
/* #define NBIF_ARG_5_4	ldr	r5, [NSP, #0] */

/* #define NBIF_RET_0	mov pc, TEMP_LR */
/* #define NBIF_RET_1	mov pc, TEMP_LR */
/* #define NBIF_RET_2	mov pc, TEMP_LR */
/* #define NBIF_RET_3	mov pc, TEMP_LR */
/* #define NBIF_RET_5	add	NSP, NSP, #8
	mov pc, TEMP_LR */

/* #define QUICK_CALL_RET_F_0 b F */
/* #define QUICK_CALL_RET_F_1 b F */
/* #define QUICK_CALL_RET_F_2 b F */
/* #define QUICK_CALL_RET_F_3 b F */
/* #define QUICK_CALL_RET_F_5 add NSP, NSP, #8 ; b F */

#endif /* HIPE_ARM_ASM_H */

#include "config.h"
#include "hipe_literals.h"

	.text
	.p2align 2

#if defined(ERTS_ENABLE_LOCK_CHECK) && defined(ERTS_SMP)
#  define CALL_BIF(F)	ldr r14, =F; str r14, [r0, #P_BIF_CALLEE]; bl hipe_debug_bif_wrapper
#else
#  define CALL_BIF(F)	bl	F
#endif



/*
 * standard_bif_interface_1(nbif_name, cbif_name)
 * standard_bif_interface_2(nbif_name, cbif_name)
 * standard_bif_interface_3(nbif_name, cbif_name)
 * standard_bif_interface_0(nbif_name, cbif_name)
 *
 * Generate native interface for a BIF with 1-3 parameters and
 * standard failure mode.
 */








/*
 * gc_bif_interface_0(nbif_name, cbif_name)
 * gc_bif_interface_1(nbif_name, cbif_name)
 * gc_bif_interface_2(nbif_name, cbif_name)
 *
 * Generate native interface for a BIF with 0-2 parameters and
 * standard failure mode.
 * The BIF may do a GC.
 */






/*
 * gc_nofail_primop_interface_1(nbif_name, cbif_name)
 *
 * Generate native interface for a primop with implicit P
 * parameter, 1 ordinary parameter and no failure mode.
 * The primop may do a GC.
 */


/*
 * nofail_primop_interface_0(nbif_name, cbif_name)
 * nofail_primop_interface_1(nbif_name, cbif_name)
 * nofail_primop_interface_2(nbif_name, cbif_name)
 * nofail_primop_interface_3(nbif_name, cbif_name)
 *
 * Generate native interface for a primop with implicit P
 * parameter, 0-3 ordinary parameters and no failure mode.
 * Also used for guard BIFs.
 */








/*
 * nocons_nofail_primop_interface_0(nbif_name, cbif_name)
 * nocons_nofail_primop_interface_1(nbif_name, cbif_name)
 * nocons_nofail_primop_interface_2(nbif_name, cbif_name)
 * nocons_nofail_primop_interface_3(nbif_name, cbif_name)
 * nocons_nofail_primop_interface_5(nbif_name, cbif_name)
 *
 * Generate native interface for a primop with implicit P
 * parameter, 0-3 or 5 ordinary parameters, and no failure mode.
 * The primop cannot CONS or gc.
 */










/*
 * noproc_primop_interface_0(nbif_name, cbif_name)
 * noproc_primop_interface_1(nbif_name, cbif_name)
 * noproc_primop_interface_2(nbif_name, cbif_name)
 * noproc_primop_interface_3(nbif_name, cbif_name)
 * noproc_primop_interface_5(nbif_name, cbif_name)
 *
 * Generate native interface for a primop with no implicit P
 * parameter, 0-3 or 5 ordinary parameters, and no failure mode.
 * The primop cannot CONS or gc.
 */










/*
 * %CopyrightBegin%
 *
 * Copyright Ericsson AB 2004-2014. All Rights Reserved.
 *
 * The contents of this file are subject to the Erlang Public License,
 * Version 1.1, (the "License"); you may not use this file except in
 * compliance with the License. You should have received a copy of the
 * Erlang Public License along with this software. If not, it can be
 * retrieved online at http://www.erlang.org/.
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * %CopyrightEnd%
 */
/*
 *
 * List all non architecture-specific BIFs and primops, and
 * classify each as belonging to one of the classes below.
 * This list is included in hipe_${ARCH}_bifs.m4, which is
 * responsible for translating these classifications to the
 * best possible native code wrappers.
 *
 * XXX: We should have a more detailed BIF classification
 * with a number of orthogonal properties (e.g., UPDATES_HP,
 * NEEDS_NSP, CAN_FAIL, CAN_GC, etc), from which we should
 * generate appropriate interfaces.
 *
 * The classification is expressed in terms of the resources
 * and BIF failure modes described below.
 *
 * Resources:
 * - NSP: native stack pointer
 *   NSP is read by GC BIFs and primops, and hipe_handle_exception().
 *   NSP is updated at compiler-inserted calls to hipe_inc_nstack().
 *   No other BIF or primop may access NSP.
 * - NSP_LIMIT: native stack limit
 *   NSP_LIMIT is only updated at compiler-inserted calls to inc_stack.
 *   Everywhere else, the cached value equals the value stored in P.
 * - NRA: native return address
 *   NRA is read by GC BIFs and primops, and hipe_handle_exception().
 *   No BIF or primop may update NRA.
 * - HP: heap pointer
 *   All BIFs can read and update HP.
 *   Primops with access to P that do not access HP are called "nocons".
 * - HP_LIMIT: heap limit
 *   HP_LIMIT is only updated by GC BIFs and primops.
 *   Everywhere else, the cached value equals the value stored in P.
 * - FCALLS: reduction counter
 *   All BIFs can read and update FCALLS (because BEAM abuses FCALLS
 *   to trigger GCs). XXX: can we avoid that overhead?
 *   All nocons primops do not access FCALLS.
 *   All other primops with access to P can read and update FCALLS.
 * - P: pointer to the state record for the process
 *
 * BIF failure modes:
 * - none: may not signal any exception
 *   The BIF wrapper needs no checks before returning.
 * - standard: may signal any exception
 *   The BIF wrapper must check for an exception before returning.
 *   Zero-arity BIFs signal no exceptions, except in a small number
 *   of cases explicitly enumerated here.
 */

/****************************************************************
 *			BIF CLASS DESCRIPTIONS			*
 ****************************************************************/

/*
 * standard_bif_interface_0(nbif_name, cbif_name)
 * standard_bif_interface_1(nbif_name, cbif_name)
 * standard_bif_interface_2(nbif_name, cbif_name)
 * standard_bif_interface_3(nbif_name, cbif_name)
 *
 * A BIF with implicit P parameter, 0-3 ordinary parameters,
 * which may fail.
 * HP and FCALLS may be read and updated.
 * HP_LIMIT, NSP, NSP_LIMIT, and NRA may not be accessed.
 */

/*
 * nofail_primop_interface_0(nbif_name, cbif_name)
 * nofail_primop_interface_1(nbif_name, cbif_name)
 * nofail_primop_interface_2(nbif_name, cbif_name)
 * nofail_primop_interface_3(nbif_name, cbif_name)
 *
 * A primop or guard BIF with no failure mode, otherwise
 * identical to standard_bif_interface_N.
 */

/*
 * gc_bif_interface_0(nbif_name, cbif_name)
 * gc_bif_interface_1(nbif_name, cbif_name)
 * gc_bif_interface_2(nbif_name, cbif_name)
 *
 * A BIF which may do a GC or walk the native stack.
 * May read NSP, NSP_LIMIT, NRA, HP, HP_LIMIT, and FCALLS.
 * May update HP, HP_LIMIT, and FCALLS.
 * May not update NSP, NSP_LIMIT, or NRA.
 * Otherwise identical to standard_bif_interface_N.
 */

/*
 * gc_nofail_primop_interface_1(nbif_name, cbif_name)
 *
 * A primop with implicit P parameter, 1 ordinary parameter,
 * and no failure mode.
 * May read NSP, NSP_LIMIT, NRA, HP, HP_LIMIT, and FCALLS.
 * May update HP, HP_LIMIT, and FCALLS.
 * May not update NSP, NSP_LIMIT, or NRA.
 */

/*
 * nocons_nofail_primop_interface_0(nbif_name, cbif_name)
 * nocons_nofail_primop_interface_1(nbif_name, cbif_name)
 * nocons_nofail_primop_interface_2(nbif_name, cbif_name)
 * nocons_nofail_primop_interface_3(nbif_name, cbif_name)
 * nocons_nofail_primop_interface_5(nbif_name, cbif_name)
 *
 * A primop with implicit P parameter, 0-3 or 5 ordinary parameters,
 * and no failure mode.
 * HP, HP_LIMIT, FCALLS, NSP, NSP_LIMIT, and NRA may not be accessed.
 */

/*
 * noproc_primop_interface_0(nbif_name, cbif_name)
 * noproc_primop_interface_1(nbif_name, cbif_name)
 * noproc_primop_interface_2(nbif_name, cbif_name)
 * noproc_primop_interface_3(nbif_name, cbif_name)
 * noproc_primop_interface_5(nbif_name, cbif_name)
 *
 * A primop with no P parameter, 0-3 or 5 ordinary parameters,
 * and no failure mode.
 * HP, HP_LIMIT, FCALLS, NSP, NSP_LIMIT, and NRA may not be accessed.
 */

/****************************************************************
 *			BIF CLASSIFICATION			*
 ****************************************************************/

/*
 * Zero-arity BIFs that can fail.
 */

#ifndef HAVE_nbif_processes_0
#define HAVE_nbif_processes_0
	.global	nbif_processes_0
nbif_processes_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(processes_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_processes_0, .-nbif_processes_0
	.type	nbif_processes_0, %function
#endif

#ifndef HAVE_nbif_ports_0
#define HAVE_nbif_ports_0
	.global	nbif_ports_0
nbif_ports_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(ports_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ports_0, .-nbif_ports_0
	.type	nbif_ports_0, %function
#endif

/*
 * BIFs and primops that may do a GC (change heap limit and walk the native stack).
 * XXX: erase/1 and put/2 cannot fail
 */

#ifndef HAVE_nbif_erts_internal_check_process_code_2
#define HAVE_nbif_erts_internal_check_process_code_2
	.global	nbif_erts_internal_check_process_code_2
nbif_erts_internal_check_process_code_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_GC
        str     r1, [r0, #P_ARG0]       /* Store BIF__ARGS in def_arg_reg[] */
        str     r2, [r0, #P_ARG1]
        add     r1, r0, #P_ARG0
	CALL_BIF(hipe_erts_internal_check_process_code_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_GC
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.size	nbif_erts_internal_check_process_code_2, .-nbif_erts_internal_check_process_code_2
	.type	nbif_erts_internal_check_process_code_2, %function
#endif

#ifndef HAVE_nbif_erase_1
#define HAVE_nbif_erase_1
	.global	nbif_erase_1
nbif_erase_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_GC
        str     r1, [r0, #P_ARG0]       /* Store BIF__ARGS in def_arg_reg[] */
        add     r1, r0, #P_ARG0
	CALL_BIF(erase_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_GC
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.size	nbif_erase_1, .-nbif_erase_1
	.type	nbif_erase_1, %function
#endif

#ifndef HAVE_nbif_garbage_collect_0
#define HAVE_nbif_garbage_collect_0
	.global	nbif_garbage_collect_0
nbif_garbage_collect_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_GC
	/* ignore empty BIF__ARGS */
	CALL_BIF(garbage_collect_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. */
	RESTORE_CONTEXT_GC
	mov pc, TEMP_LR
	.size	nbif_garbage_collect_0, .-nbif_garbage_collect_0
	.type	nbif_garbage_collect_0, %function
#endif

#ifndef HAVE_nbif_gc_1
#define HAVE_nbif_gc_1
	.global	nbif_gc_1
nbif_gc_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_GC
	bl	hipe_gc

	/* Restore registers. */
	RESTORE_CONTEXT_GC
	mov pc, TEMP_LR
	.size	nbif_gc_1, .-nbif_gc_1
	.type	nbif_gc_1, %function
#endif

#ifndef HAVE_nbif_put_2
#define HAVE_nbif_put_2
	.global	nbif_put_2
nbif_put_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_GC
        str     r1, [r0, #P_ARG0]       /* Store BIF__ARGS in def_arg_reg[] */
        str     r2, [r0, #P_ARG1]
        add     r1, r0, #P_ARG0
	CALL_BIF(put_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_GC
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.size	nbif_put_2, .-nbif_put_2
	.type	nbif_put_2, %function
#endif

/*
 * Debug BIFs that need read access to the full state.
 * hipe_bifs:nstack_used_size/0 only needs read access to NSP.
 * They are classified as GC BIFs for simplicity.
 */

#ifndef HAVE_nbif_hipe_bifs_show_nstack_1
#define HAVE_nbif_hipe_bifs_show_nstack_1
	.global	nbif_hipe_bifs_show_nstack_1
nbif_hipe_bifs_show_nstack_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_GC
        str     r1, [r0, #P_ARG0]       /* Store BIF__ARGS in def_arg_reg[] */
        add     r1, r0, #P_ARG0
	CALL_BIF(hipe_show_nstack_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_GC
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.size	nbif_hipe_bifs_show_nstack_1, .-nbif_hipe_bifs_show_nstack_1
	.type	nbif_hipe_bifs_show_nstack_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_show_pcb_1
#define HAVE_nbif_hipe_bifs_show_pcb_1
	.global	nbif_hipe_bifs_show_pcb_1
nbif_hipe_bifs_show_pcb_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_GC
        str     r1, [r0, #P_ARG0]       /* Store BIF__ARGS in def_arg_reg[] */
        add     r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_show_pcb_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_GC
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.size	nbif_hipe_bifs_show_pcb_1, .-nbif_hipe_bifs_show_pcb_1
	.type	nbif_hipe_bifs_show_pcb_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_nstack_used_size_0
#define HAVE_nbif_hipe_bifs_nstack_used_size_0
	.global	nbif_hipe_bifs_nstack_used_size_0
nbif_hipe_bifs_nstack_used_size_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_GC
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_nstack_used_size_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. */
	RESTORE_CONTEXT_GC
	mov pc, TEMP_LR
	.size	nbif_hipe_bifs_nstack_used_size_0, .-nbif_hipe_bifs_nstack_used_size_0
	.type	nbif_hipe_bifs_nstack_used_size_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_debug_native_called
#define HAVE_nbif_hipe_bifs_debug_native_called
	.global	nbif_hipe_bifs_debug_native_called
nbif_hipe_bifs_debug_native_called:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_GC
        str     r1, [r0, #P_ARG0]       /* Store BIF__ARGS in def_arg_reg[] */
        str     r2, [r0, #P_ARG1]
        add     r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_debug_native_called_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_GC
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.size	nbif_hipe_bifs_debug_native_called, .-nbif_hipe_bifs_debug_native_called
	.type	nbif_hipe_bifs_debug_native_called, %function
#endif

/*
 * Arithmetic operators called indirectly by the HiPE compiler.
 */

#ifndef HAVE_nbif_add_2
#define HAVE_nbif_add_2
	.global	nbif_add_2
nbif_add_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(splus_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_add_2, .-nbif_add_2
	.type	nbif_add_2, %function
#endif

#ifndef HAVE_nbif_sub_2
#define HAVE_nbif_sub_2
	.global	nbif_sub_2
nbif_sub_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(sminus_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_sub_2, .-nbif_sub_2
	.type	nbif_sub_2, %function
#endif

#ifndef HAVE_nbif_mul_2
#define HAVE_nbif_mul_2
	.global	nbif_mul_2
nbif_mul_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(stimes_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_mul_2, .-nbif_mul_2
	.type	nbif_mul_2, %function
#endif

#ifndef HAVE_nbif_div_2
#define HAVE_nbif_div_2
	.global	nbif_div_2
nbif_div_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(div_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_div_2, .-nbif_div_2
	.type	nbif_div_2, %function
#endif

#ifndef HAVE_nbif_intdiv_2
#define HAVE_nbif_intdiv_2
	.global	nbif_intdiv_2
nbif_intdiv_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(intdiv_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_intdiv_2, .-nbif_intdiv_2
	.type	nbif_intdiv_2, %function
#endif

#ifndef HAVE_nbif_rem_2
#define HAVE_nbif_rem_2
	.global	nbif_rem_2
nbif_rem_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(rem_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_rem_2, .-nbif_rem_2
	.type	nbif_rem_2, %function
#endif

#ifndef HAVE_nbif_bsl_2
#define HAVE_nbif_bsl_2
	.global	nbif_bsl_2
nbif_bsl_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(bsl_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_bsl_2, .-nbif_bsl_2
	.type	nbif_bsl_2, %function
#endif

#ifndef HAVE_nbif_bsr_2
#define HAVE_nbif_bsr_2
	.global	nbif_bsr_2
nbif_bsr_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(bsr_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_bsr_2, .-nbif_bsr_2
	.type	nbif_bsr_2, %function
#endif

#ifndef HAVE_nbif_band_2
#define HAVE_nbif_band_2
	.global	nbif_band_2
nbif_band_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(band_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_band_2, .-nbif_band_2
	.type	nbif_band_2, %function
#endif

#ifndef HAVE_nbif_bor_2
#define HAVE_nbif_bor_2
	.global	nbif_bor_2
nbif_bor_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(bor_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_bor_2, .-nbif_bor_2
	.type	nbif_bor_2, %function
#endif

#ifndef HAVE_nbif_bxor_2
#define HAVE_nbif_bxor_2
	.global	nbif_bxor_2
nbif_bxor_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(bxor_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_bxor_2, .-nbif_bxor_2
	.type	nbif_bxor_2, %function
#endif

#ifndef HAVE_nbif_bnot_1
#define HAVE_nbif_bnot_1
	.global	nbif_bnot_1
nbif_bnot_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(bnot_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_bnot_1, .-nbif_bnot_1
	.type	nbif_bnot_1, %function
#endif

/*
 * Miscellaneous primops.
 */

#ifndef HAVE_nbif_set_timeout
#define HAVE_nbif_set_timeout
	.global	nbif_set_timeout
nbif_set_timeout:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_set_timeout)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_set_timeout, .-nbif_set_timeout
	.type	nbif_set_timeout, %function
#endif

#ifndef HAVE_nbif_conv_big_to_float
#define HAVE_nbif_conv_big_to_float
	.global	nbif_conv_big_to_float
nbif_conv_big_to_float:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_conv_big_to_float)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_conv_big_to_float, .-nbif_conv_big_to_float
	.type	nbif_conv_big_to_float, %function
#endif

#ifndef HAVE_nbif_rethrow
#define HAVE_nbif_rethrow
	.global	nbif_rethrow
nbif_rethrow:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_rethrow)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_rethrow, .-nbif_rethrow
	.type	nbif_rethrow, %function
#endif

#ifndef HAVE_nbif_find_na_or_make_stub
#define HAVE_nbif_find_na_or_make_stub
	.global	nbif_find_na_or_make_stub
nbif_find_na_or_make_stub:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_find_na_or_make_stub)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_find_na_or_make_stub, .-nbif_find_na_or_make_stub
	.type	nbif_find_na_or_make_stub, %function
#endif

#ifndef HAVE_nbif_nonclosure_address
#define HAVE_nbif_nonclosure_address
	.global	nbif_nonclosure_address
nbif_nonclosure_address:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_nonclosure_address)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_nonclosure_address, .-nbif_nonclosure_address
	.type	nbif_nonclosure_address, %function
#endif

#ifndef HAVE_nbif_fclearerror_error
#define HAVE_nbif_fclearerror_error
	.global	nbif_fclearerror_error
nbif_fclearerror_error:
	/* Set up C argument registers. */
	mov	r0, P

	/* Perform a quick save;call;restore;ret sequence. */
	b hipe_fclearerror_error
	.size	nbif_fclearerror_error, .-nbif_fclearerror_error
	.type	nbif_fclearerror_error, %function
#endif

/*
 * Mbox primops with implicit P parameter.
 */

#ifndef HAVE_nbif_select_msg
#define HAVE_nbif_select_msg
	.global	nbif_select_msg
nbif_select_msg:
	/* Set up C argument registers. */
	mov	r0, P

	/* Perform a quick save;call;restore;ret sequence. */
	b hipe_select_msg
	.size	nbif_select_msg, .-nbif_select_msg
	.type	nbif_select_msg, %function
#endif

/*
 * Primops without any P parameter.
 * These cannot CONS or gc.
 */

#ifndef HAVE_nbif_cmp_2
#define HAVE_nbif_cmp_2
	.global	nbif_cmp_2
nbif_cmp_2:
	/* Set up C argument registers. */
	mov	r0, r1
	mov	r1, r2

	/* Perform a quick save;call;restore;ret sequence. */
	b cmp
	.size	nbif_cmp_2, .-nbif_cmp_2
	.type	nbif_cmp_2, %function
#endif

#ifndef HAVE_nbif_eq_2
#define HAVE_nbif_eq_2
	.global	nbif_eq_2
nbif_eq_2:
	/* Set up C argument registers. */
	mov	r0, r1
	mov	r1, r2

	/* Perform a quick save;call;restore;ret sequence. */
	b eq
	.size	nbif_eq_2, .-nbif_eq_2
	.type	nbif_eq_2, %function
#endif

/*
 * Bit-syntax primops with implicit P parameter.
 * XXX: all of the _2 versions cons on the ordinary heap
 * XXX: all of them can cons and thus update FCALLS
 */

#ifndef HAVE_nbif_bs_get_integer_2
#define HAVE_nbif_bs_get_integer_2
	.global	nbif_bs_get_integer_2
nbif_bs_get_integer_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	bl	erts_bs_get_integer_2
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. */
	RESTORE_CONTEXT_BIF
	mov pc, TEMP_LR
	.size	nbif_bs_get_integer_2, .-nbif_bs_get_integer_2
	.type	nbif_bs_get_integer_2, %function
#endif

#ifndef HAVE_nbif_bs_get_binary_2
#define HAVE_nbif_bs_get_binary_2
	.global	nbif_bs_get_binary_2
nbif_bs_get_binary_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	bl	erts_bs_get_binary_2
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. */
	RESTORE_CONTEXT_BIF
	mov pc, TEMP_LR
	.size	nbif_bs_get_binary_2, .-nbif_bs_get_binary_2
	.type	nbif_bs_get_binary_2, %function
#endif

#ifndef HAVE_nbif_bs_get_float_2
#define HAVE_nbif_bs_get_float_2
	.global	nbif_bs_get_float_2
nbif_bs_get_float_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	bl	erts_bs_get_float_2
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. */
	RESTORE_CONTEXT_BIF
	mov pc, TEMP_LR
	.size	nbif_bs_get_float_2, .-nbif_bs_get_float_2
	.type	nbif_bs_get_float_2, %function
#endif

#ifndef HAVE_nbif_bs_put_utf8
#define HAVE_nbif_bs_put_utf8
	.global	nbif_bs_put_utf8
nbif_bs_put_utf8:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bs_put_utf8)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_bs_put_utf8, .-nbif_bs_put_utf8
	.type	nbif_bs_put_utf8, %function
#endif

#ifndef HAVE_nbif_bs_put_utf16be
#define HAVE_nbif_bs_put_utf16be
	.global	nbif_bs_put_utf16be
nbif_bs_put_utf16be:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bs_put_utf16be)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_bs_put_utf16be, .-nbif_bs_put_utf16be
	.type	nbif_bs_put_utf16be, %function
#endif

#ifndef HAVE_nbif_bs_put_utf16le
#define HAVE_nbif_bs_put_utf16le
	.global	nbif_bs_put_utf16le
nbif_bs_put_utf16le:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bs_put_utf16le)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_bs_put_utf16le, .-nbif_bs_put_utf16le
	.type	nbif_bs_put_utf16le, %function
#endif

#ifndef HAVE_nbif_bs_validate_unicode
#define HAVE_nbif_bs_validate_unicode
	.global	nbif_bs_validate_unicode
nbif_bs_validate_unicode:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bs_validate_unicode)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_bs_validate_unicode, .-nbif_bs_validate_unicode
	.type	nbif_bs_validate_unicode, %function
#endif

/*
 * Bit-syntax primops without any P parameter.
 * These cannot CONS or gc.
 */

#ifndef HAVE_nbif_bs_allocate
#define HAVE_nbif_bs_allocate
	.global	nbif_bs_allocate
nbif_bs_allocate:
	/* Set up C argument registers. */
	mov	r0, r1

	/* Perform a quick save;call;restore;ret sequence. */
	b hipe_bs_allocate
	.size	nbif_bs_allocate, .-nbif_bs_allocate
	.type	nbif_bs_allocate, %function
#endif

#ifndef HAVE_nbif_bs_reallocate
#define HAVE_nbif_bs_reallocate
	.global	nbif_bs_reallocate
nbif_bs_reallocate:
	/* Set up C argument registers. */
	mov	r0, r1
	mov	r1, r2

	/* Perform a quick save;call;restore;ret sequence. */
	b hipe_bs_reallocate
	.size	nbif_bs_reallocate, .-nbif_bs_reallocate
	.type	nbif_bs_reallocate, %function
#endif

#ifndef HAVE_nbif_bs_utf8_size
#define HAVE_nbif_bs_utf8_size
	.global	nbif_bs_utf8_size
nbif_bs_utf8_size:
	/* Set up C argument registers. */
	mov	r0, r1

	/* Perform a quick save;call;restore;ret sequence. */
	b hipe_bs_utf8_size
	.size	nbif_bs_utf8_size, .-nbif_bs_utf8_size
	.type	nbif_bs_utf8_size, %function
#endif

#ifndef HAVE_nbif_bs_get_utf8
#define HAVE_nbif_bs_get_utf8
	.global	nbif_bs_get_utf8
nbif_bs_get_utf8:
	/* Set up C argument registers. */
	mov	r0, r1

	/* Perform a quick save;call;restore;ret sequence. */
	b erts_bs_get_utf8
	.size	nbif_bs_get_utf8, .-nbif_bs_get_utf8
	.type	nbif_bs_get_utf8, %function
#endif

#ifndef HAVE_nbif_bs_utf16_size
#define HAVE_nbif_bs_utf16_size
	.global	nbif_bs_utf16_size
nbif_bs_utf16_size:
	/* Set up C argument registers. */
	mov	r0, r1

	/* Perform a quick save;call;restore;ret sequence. */
	b hipe_bs_utf16_size
	.size	nbif_bs_utf16_size, .-nbif_bs_utf16_size
	.type	nbif_bs_utf16_size, %function
#endif

#ifndef HAVE_nbif_bs_get_utf16
#define HAVE_nbif_bs_get_utf16
	.global	nbif_bs_get_utf16
nbif_bs_get_utf16:
	/* Set up C argument registers. */
	mov	r0, r1
	mov	r1, r2

	/* Perform a quick save;call;restore;ret sequence. */
	b erts_bs_get_utf16
	.size	nbif_bs_get_utf16, .-nbif_bs_get_utf16
	.type	nbif_bs_get_utf16, %function
#endif

#ifndef HAVE_nbif_bs_validate_unicode_retract
#define HAVE_nbif_bs_validate_unicode_retract
	.global	nbif_bs_validate_unicode_retract
nbif_bs_validate_unicode_retract:
	/* Set up C argument registers. */
	mov	r0, r1
	mov	r1, r2

	/* Perform a quick save;call;restore;ret sequence. */
	b hipe_bs_validate_unicode_retract
	.size	nbif_bs_validate_unicode_retract, .-nbif_bs_validate_unicode_retract
	.type	nbif_bs_validate_unicode_retract, %function
#endif

/*
 * Bit-syntax primops. The ERTS_SMP runtime system requires P,
 * hence the use of nocons_nofail_primop_interface_N().
 * When ERTS_SMP is disabled, noproc_primop_interface_N()
 * should be used instead.
 */

#ifndef HAVE_nbif_bs_put_small_float
#define HAVE_nbif_bs_put_small_float
	.global	nbif_bs_put_small_float
nbif_bs_put_small_float:
	/* Set up C argument stack. */
	ldr	r0, [NSP, #4]
	str	r0, [sp, #0]
	ldr	r0, [NSP, #0]
	str	r0, [sp, #4]

	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Perform a quick save;call;restore;ret sequence. */
	add NSP, NSP, #8 ; b hipe_bs_put_small_float
	.size	nbif_bs_put_small_float, .-nbif_bs_put_small_float
	.type	nbif_bs_put_small_float, %function
#endif

#ifndef HAVE_nbif_bs_put_bits
#define HAVE_nbif_bs_put_bits
	.global	nbif_bs_put_bits
nbif_bs_put_bits:
	/* Set up C argument registers. */
	mov	r0, r1
	mov	r1, r2
	mov	r2, r3
	ldr	r3, [NSP, #4]
	ldr	r4, [NSP, #0]
	str	r4, [sp, #0]

	/* Perform a quick save;call;restore;ret sequence. */
	add NSP, NSP, #8 ; b hipe_bs_put_bits
	.size	nbif_bs_put_bits, .-nbif_bs_put_bits
	.type	nbif_bs_put_bits, %function
#endif


#ifndef HAVE_nbif_bs_put_big_integer
#define HAVE_nbif_bs_put_big_integer
	.global	nbif_bs_put_big_integer
nbif_bs_put_big_integer:
	/* Set up C argument registers. */
	mov	r0, r1
	mov	r1, r2
	mov	r2, r3
	ldr	r3, [NSP, #4]
	ldr	r4, [NSP, #0]
	str	r4, [sp, #0]

	/* Perform a quick save;call;restore;ret sequence. */
	add NSP, NSP, #8 ; b hipe_bs_put_big_integer
	.size	nbif_bs_put_big_integer, .-nbif_bs_put_big_integer
	.type	nbif_bs_put_big_integer, %function
#endif


#ifndef HAVE_nbif_check_get_msg
#define HAVE_nbif_check_get_msg
	.global	nbif_check_get_msg
nbif_check_get_msg:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_GC
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_check_get_msg)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. */
	RESTORE_CONTEXT_GC
	mov pc, TEMP_LR
	.size	nbif_check_get_msg, .-nbif_check_get_msg
	.type	nbif_check_get_msg, %function
#endif

#ifdef NO_FPE_SIGNALS

#ifndef HAVE_nbif_emulate_fpe
#define HAVE_nbif_emulate_fpe
	.global	nbif_emulate_fpe
nbif_emulate_fpe:
	/* Set up C argument registers. */
	mov	r0, P

	/* Perform a quick save;call;restore;ret sequence. */
	b hipe_emulate_fpe
	.size	nbif_emulate_fpe, .-nbif_emulate_fpe
	.type	nbif_emulate_fpe, %function
#endif
#endif

/*
 * SMP-specific stuff
 */

/*
 * Standard BIFs.
 * BIF_LIST(ModuleAtom,FunctionAtom,Arity,CFun,Index)
 */

/* BIFs that disable GC while trapping are called via a wrapper
 * to reserve stack space for the "trap frame".
 */



/*
 *  Warning: Do not edit this file.  It was automatically
 *  generated by 'make_tables' on Thu Aug  6 16:11:45 2015.
 */


#ifndef HAVE_nbif_abs_1
#define HAVE_nbif_abs_1
	.global	nbif_abs_1
nbif_abs_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(abs_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_abs_1, .-nbif_abs_1
	.type	nbif_abs_1, %function
#endif

#ifndef HAVE_nbif_adler32_1
#define HAVE_nbif_adler32_1
	.global	nbif_adler32_1
nbif_adler32_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(adler32_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_adler32_1, .-nbif_adler32_1
	.type	nbif_adler32_1, %function
#endif

#ifndef HAVE_nbif_adler32_2
#define HAVE_nbif_adler32_2
	.global	nbif_adler32_2
nbif_adler32_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(adler32_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_adler32_2, .-nbif_adler32_2
	.type	nbif_adler32_2, %function
#endif

#ifndef HAVE_nbif_adler32_combine_3
#define HAVE_nbif_adler32_combine_3
	.global	nbif_adler32_combine_3
nbif_adler32_combine_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(adler32_combine_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_adler32_combine_3, .-nbif_adler32_combine_3
	.type	nbif_adler32_combine_3, %function
#endif

#ifndef HAVE_nbif_apply_3
#define HAVE_nbif_apply_3
	.global	nbif_apply_3
nbif_apply_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(apply_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_apply_3, .-nbif_apply_3
	.type	nbif_apply_3, %function
#endif

#ifndef HAVE_nbif_atom_to_list_1
#define HAVE_nbif_atom_to_list_1
	.global	nbif_atom_to_list_1
nbif_atom_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(atom_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_atom_to_list_1, .-nbif_atom_to_list_1
	.type	nbif_atom_to_list_1, %function
#endif

#ifndef HAVE_nbif_binary_to_list_1
#define HAVE_nbif_binary_to_list_1
	.global	nbif_binary_to_list_1
nbif_binary_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_wrapper_binary_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_to_list_1, .-nbif_binary_to_list_1
	.type	nbif_binary_to_list_1, %function
#endif

#ifndef HAVE_nbif_binary_to_list_3
#define HAVE_nbif_binary_to_list_3
	.global	nbif_binary_to_list_3
nbif_binary_to_list_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_wrapper_binary_to_list_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_to_list_3, .-nbif_binary_to_list_3
	.type	nbif_binary_to_list_3, %function
#endif

#ifndef HAVE_nbif_binary_to_term_1
#define HAVE_nbif_binary_to_term_1
	.global	nbif_binary_to_term_1
nbif_binary_to_term_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_wrapper_binary_to_term_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_to_term_1, .-nbif_binary_to_term_1
	.type	nbif_binary_to_term_1, %function
#endif

#ifndef HAVE_nbif_crc32_1
#define HAVE_nbif_crc32_1
	.global	nbif_crc32_1
nbif_crc32_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(crc32_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_crc32_1, .-nbif_crc32_1
	.type	nbif_crc32_1, %function
#endif

#ifndef HAVE_nbif_crc32_2
#define HAVE_nbif_crc32_2
	.global	nbif_crc32_2
nbif_crc32_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(crc32_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_crc32_2, .-nbif_crc32_2
	.type	nbif_crc32_2, %function
#endif

#ifndef HAVE_nbif_crc32_combine_3
#define HAVE_nbif_crc32_combine_3
	.global	nbif_crc32_combine_3
nbif_crc32_combine_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(crc32_combine_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_crc32_combine_3, .-nbif_crc32_combine_3
	.type	nbif_crc32_combine_3, %function
#endif

#ifndef HAVE_nbif_date_0
#define HAVE_nbif_date_0
	.global	nbif_date_0
nbif_date_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(date_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_date_0, .-nbif_date_0
	.type	nbif_date_0, %function
#endif

#ifndef HAVE_nbif_delete_module_1
#define HAVE_nbif_delete_module_1
	.global	nbif_delete_module_1
nbif_delete_module_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(delete_module_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_delete_module_1, .-nbif_delete_module_1
	.type	nbif_delete_module_1, %function
#endif

#ifndef HAVE_nbif_display_1
#define HAVE_nbif_display_1
	.global	nbif_display_1
nbif_display_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(display_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_display_1, .-nbif_display_1
	.type	nbif_display_1, %function
#endif

#ifndef HAVE_nbif_display_string_1
#define HAVE_nbif_display_string_1
	.global	nbif_display_string_1
nbif_display_string_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(display_string_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_display_string_1, .-nbif_display_string_1
	.type	nbif_display_string_1, %function
#endif

#ifndef HAVE_nbif_display_nl_0
#define HAVE_nbif_display_nl_0
	.global	nbif_display_nl_0
nbif_display_nl_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(display_nl_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_display_nl_0, .-nbif_display_nl_0
	.type	nbif_display_nl_0, %function
#endif

#ifndef HAVE_nbif_element_2
#define HAVE_nbif_element_2
	.global	nbif_element_2
nbif_element_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(element_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_element_2, .-nbif_element_2
	.type	nbif_element_2, %function
#endif

#ifndef HAVE_nbif_erase_0
#define HAVE_nbif_erase_0
	.global	nbif_erase_0
nbif_erase_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(erase_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erase_0, .-nbif_erase_0
	.type	nbif_erase_0, %function
#endif

#ifndef HAVE_nbif_erase_1
#define HAVE_nbif_erase_1
	.global	nbif_erase_1
nbif_erase_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erase_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erase_1, .-nbif_erase_1
	.type	nbif_erase_1, %function
#endif

#ifndef HAVE_nbif_exit_1
#define HAVE_nbif_exit_1
	.global	nbif_exit_1
nbif_exit_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(exit_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_exit_1, .-nbif_exit_1
	.type	nbif_exit_1, %function
#endif

#ifndef HAVE_nbif_exit_2
#define HAVE_nbif_exit_2
	.global	nbif_exit_2
nbif_exit_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(exit_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_exit_2, .-nbif_exit_2
	.type	nbif_exit_2, %function
#endif

#ifndef HAVE_nbif_external_size_1
#define HAVE_nbif_external_size_1
	.global	nbif_external_size_1
nbif_external_size_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(external_size_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_external_size_1, .-nbif_external_size_1
	.type	nbif_external_size_1, %function
#endif

#ifndef HAVE_nbif_external_size_2
#define HAVE_nbif_external_size_2
	.global	nbif_external_size_2
nbif_external_size_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(external_size_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_external_size_2, .-nbif_external_size_2
	.type	nbif_external_size_2, %function
#endif

#ifndef HAVE_nbif_float_1
#define HAVE_nbif_float_1
	.global	nbif_float_1
nbif_float_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(float_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_float_1, .-nbif_float_1
	.type	nbif_float_1, %function
#endif

#ifndef HAVE_nbif_float_to_list_1
#define HAVE_nbif_float_to_list_1
	.global	nbif_float_to_list_1
nbif_float_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(float_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_float_to_list_1, .-nbif_float_to_list_1
	.type	nbif_float_to_list_1, %function
#endif

#ifndef HAVE_nbif_float_to_list_2
#define HAVE_nbif_float_to_list_2
	.global	nbif_float_to_list_2
nbif_float_to_list_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(float_to_list_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_float_to_list_2, .-nbif_float_to_list_2
	.type	nbif_float_to_list_2, %function
#endif

#ifndef HAVE_nbif_fun_info_2
#define HAVE_nbif_fun_info_2
	.global	nbif_fun_info_2
nbif_fun_info_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(fun_info_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_fun_info_2, .-nbif_fun_info_2
	.type	nbif_fun_info_2, %function
#endif

#ifndef HAVE_nbif_garbage_collect_0
#define HAVE_nbif_garbage_collect_0
	.global	nbif_garbage_collect_0
nbif_garbage_collect_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(garbage_collect_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_garbage_collect_0, .-nbif_garbage_collect_0
	.type	nbif_garbage_collect_0, %function
#endif

#ifndef HAVE_nbif_get_0
#define HAVE_nbif_get_0
	.global	nbif_get_0
nbif_get_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(get_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_get_0, .-nbif_get_0
	.type	nbif_get_0, %function
#endif

#ifndef HAVE_nbif_get_1
#define HAVE_nbif_get_1
	.global	nbif_get_1
nbif_get_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(get_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_get_1, .-nbif_get_1
	.type	nbif_get_1, %function
#endif

#ifndef HAVE_nbif_get_keys_1
#define HAVE_nbif_get_keys_1
	.global	nbif_get_keys_1
nbif_get_keys_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(get_keys_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_get_keys_1, .-nbif_get_keys_1
	.type	nbif_get_keys_1, %function
#endif

#ifndef HAVE_nbif_group_leader_0
#define HAVE_nbif_group_leader_0
	.global	nbif_group_leader_0
nbif_group_leader_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(group_leader_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_group_leader_0, .-nbif_group_leader_0
	.type	nbif_group_leader_0, %function
#endif

#ifndef HAVE_nbif_group_leader_2
#define HAVE_nbif_group_leader_2
	.global	nbif_group_leader_2
nbif_group_leader_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(group_leader_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_group_leader_2, .-nbif_group_leader_2
	.type	nbif_group_leader_2, %function
#endif

#ifndef HAVE_nbif_halt_0
#define HAVE_nbif_halt_0
	.global	nbif_halt_0
nbif_halt_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(halt_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_halt_0, .-nbif_halt_0
	.type	nbif_halt_0, %function
#endif

#ifndef HAVE_nbif_halt_1
#define HAVE_nbif_halt_1
	.global	nbif_halt_1
nbif_halt_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(halt_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_halt_1, .-nbif_halt_1
	.type	nbif_halt_1, %function
#endif

#ifndef HAVE_nbif_halt_2
#define HAVE_nbif_halt_2
	.global	nbif_halt_2
nbif_halt_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(halt_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_halt_2, .-nbif_halt_2
	.type	nbif_halt_2, %function
#endif

#ifndef HAVE_nbif_phash_2
#define HAVE_nbif_phash_2
	.global	nbif_phash_2
nbif_phash_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(phash_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_phash_2, .-nbif_phash_2
	.type	nbif_phash_2, %function
#endif

#ifndef HAVE_nbif_phash2_1
#define HAVE_nbif_phash2_1
	.global	nbif_phash2_1
nbif_phash2_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(phash2_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_phash2_1, .-nbif_phash2_1
	.type	nbif_phash2_1, %function
#endif

#ifndef HAVE_nbif_phash2_2
#define HAVE_nbif_phash2_2
	.global	nbif_phash2_2
nbif_phash2_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(phash2_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_phash2_2, .-nbif_phash2_2
	.type	nbif_phash2_2, %function
#endif

#ifndef HAVE_nbif_hd_1
#define HAVE_nbif_hd_1
	.global	nbif_hd_1
nbif_hd_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hd_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hd_1, .-nbif_hd_1
	.type	nbif_hd_1, %function
#endif

#ifndef HAVE_nbif_integer_to_list_1
#define HAVE_nbif_integer_to_list_1
	.global	nbif_integer_to_list_1
nbif_integer_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(integer_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_integer_to_list_1, .-nbif_integer_to_list_1
	.type	nbif_integer_to_list_1, %function
#endif

#ifndef HAVE_nbif_is_alive_0
#define HAVE_nbif_is_alive_0
	.global	nbif_is_alive_0
nbif_is_alive_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(is_alive_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_is_alive_0, .-nbif_is_alive_0
	.type	nbif_is_alive_0, %function
#endif

#ifndef HAVE_nbif_length_1
#define HAVE_nbif_length_1
	.global	nbif_length_1
nbif_length_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(length_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_length_1, .-nbif_length_1
	.type	nbif_length_1, %function
#endif

#ifndef HAVE_nbif_link_1
#define HAVE_nbif_link_1
	.global	nbif_link_1
nbif_link_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(link_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_link_1, .-nbif_link_1
	.type	nbif_link_1, %function
#endif

#ifndef HAVE_nbif_list_to_atom_1
#define HAVE_nbif_list_to_atom_1
	.global	nbif_list_to_atom_1
nbif_list_to_atom_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(list_to_atom_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_list_to_atom_1, .-nbif_list_to_atom_1
	.type	nbif_list_to_atom_1, %function
#endif

#ifndef HAVE_nbif_list_to_binary_1
#define HAVE_nbif_list_to_binary_1
	.global	nbif_list_to_binary_1
nbif_list_to_binary_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_wrapper_list_to_binary_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_list_to_binary_1, .-nbif_list_to_binary_1
	.type	nbif_list_to_binary_1, %function
#endif

#ifndef HAVE_nbif_list_to_float_1
#define HAVE_nbif_list_to_float_1
	.global	nbif_list_to_float_1
nbif_list_to_float_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(list_to_float_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_list_to_float_1, .-nbif_list_to_float_1
	.type	nbif_list_to_float_1, %function
#endif

#ifndef HAVE_nbif_list_to_integer_1
#define HAVE_nbif_list_to_integer_1
	.global	nbif_list_to_integer_1
nbif_list_to_integer_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(list_to_integer_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_list_to_integer_1, .-nbif_list_to_integer_1
	.type	nbif_list_to_integer_1, %function
#endif

#ifndef HAVE_nbif_list_to_pid_1
#define HAVE_nbif_list_to_pid_1
	.global	nbif_list_to_pid_1
nbif_list_to_pid_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(list_to_pid_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_list_to_pid_1, .-nbif_list_to_pid_1
	.type	nbif_list_to_pid_1, %function
#endif

#ifndef HAVE_nbif_list_to_tuple_1
#define HAVE_nbif_list_to_tuple_1
	.global	nbif_list_to_tuple_1
nbif_list_to_tuple_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(list_to_tuple_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_list_to_tuple_1, .-nbif_list_to_tuple_1
	.type	nbif_list_to_tuple_1, %function
#endif

#ifndef HAVE_nbif_loaded_0
#define HAVE_nbif_loaded_0
	.global	nbif_loaded_0
nbif_loaded_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(loaded_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_loaded_0, .-nbif_loaded_0
	.type	nbif_loaded_0, %function
#endif

#ifndef HAVE_nbif_localtime_0
#define HAVE_nbif_localtime_0
	.global	nbif_localtime_0
nbif_localtime_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(localtime_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_localtime_0, .-nbif_localtime_0
	.type	nbif_localtime_0, %function
#endif

#ifndef HAVE_nbif_localtime_to_universaltime_2
#define HAVE_nbif_localtime_to_universaltime_2
	.global	nbif_localtime_to_universaltime_2
nbif_localtime_to_universaltime_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(localtime_to_universaltime_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_localtime_to_universaltime_2, .-nbif_localtime_to_universaltime_2
	.type	nbif_localtime_to_universaltime_2, %function
#endif

#ifndef HAVE_nbif_make_ref_0
#define HAVE_nbif_make_ref_0
	.global	nbif_make_ref_0
nbif_make_ref_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(make_ref_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_make_ref_0, .-nbif_make_ref_0
	.type	nbif_make_ref_0, %function
#endif

#ifndef HAVE_nbif_md5_1
#define HAVE_nbif_md5_1
	.global	nbif_md5_1
nbif_md5_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(md5_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_md5_1, .-nbif_md5_1
	.type	nbif_md5_1, %function
#endif

#ifndef HAVE_nbif_md5_init_0
#define HAVE_nbif_md5_init_0
	.global	nbif_md5_init_0
nbif_md5_init_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(md5_init_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_md5_init_0, .-nbif_md5_init_0
	.type	nbif_md5_init_0, %function
#endif

#ifndef HAVE_nbif_md5_update_2
#define HAVE_nbif_md5_update_2
	.global	nbif_md5_update_2
nbif_md5_update_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(md5_update_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_md5_update_2, .-nbif_md5_update_2
	.type	nbif_md5_update_2, %function
#endif

#ifndef HAVE_nbif_md5_final_1
#define HAVE_nbif_md5_final_1
	.global	nbif_md5_final_1
nbif_md5_final_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(md5_final_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_md5_final_1, .-nbif_md5_final_1
	.type	nbif_md5_final_1, %function
#endif

#ifndef HAVE_nbif_module_loaded_1
#define HAVE_nbif_module_loaded_1
	.global	nbif_module_loaded_1
nbif_module_loaded_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(module_loaded_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_module_loaded_1, .-nbif_module_loaded_1
	.type	nbif_module_loaded_1, %function
#endif

#ifndef HAVE_nbif_function_exported_3
#define HAVE_nbif_function_exported_3
	.global	nbif_function_exported_3
nbif_function_exported_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(function_exported_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_function_exported_3, .-nbif_function_exported_3
	.type	nbif_function_exported_3, %function
#endif

#ifndef HAVE_nbif_monitor_node_2
#define HAVE_nbif_monitor_node_2
	.global	nbif_monitor_node_2
nbif_monitor_node_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(monitor_node_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_monitor_node_2, .-nbif_monitor_node_2
	.type	nbif_monitor_node_2, %function
#endif

#ifndef HAVE_nbif_monitor_node_3
#define HAVE_nbif_monitor_node_3
	.global	nbif_monitor_node_3
nbif_monitor_node_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(monitor_node_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_monitor_node_3, .-nbif_monitor_node_3
	.type	nbif_monitor_node_3, %function
#endif

#ifndef HAVE_nbif_node_1
#define HAVE_nbif_node_1
	.global	nbif_node_1
nbif_node_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(node_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_node_1, .-nbif_node_1
	.type	nbif_node_1, %function
#endif

#ifndef HAVE_nbif_node_0
#define HAVE_nbif_node_0
	.global	nbif_node_0
nbif_node_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(node_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_node_0, .-nbif_node_0
	.type	nbif_node_0, %function
#endif

#ifndef HAVE_nbif_nodes_1
#define HAVE_nbif_nodes_1
	.global	nbif_nodes_1
nbif_nodes_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(nodes_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_nodes_1, .-nbif_nodes_1
	.type	nbif_nodes_1, %function
#endif

#ifndef HAVE_nbif_now_0
#define HAVE_nbif_now_0
	.global	nbif_now_0
nbif_now_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(now_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_now_0, .-nbif_now_0
	.type	nbif_now_0, %function
#endif

#ifndef HAVE_nbif_open_port_2
#define HAVE_nbif_open_port_2
	.global	nbif_open_port_2
nbif_open_port_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(open_port_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_open_port_2, .-nbif_open_port_2
	.type	nbif_open_port_2, %function
#endif

#ifndef HAVE_nbif_pid_to_list_1
#define HAVE_nbif_pid_to_list_1
	.global	nbif_pid_to_list_1
nbif_pid_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(pid_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_pid_to_list_1, .-nbif_pid_to_list_1
	.type	nbif_pid_to_list_1, %function
#endif

#ifndef HAVE_nbif_ports_0
#define HAVE_nbif_ports_0
	.global	nbif_ports_0
nbif_ports_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(ports_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ports_0, .-nbif_ports_0
	.type	nbif_ports_0, %function
#endif

#ifndef HAVE_nbif_pre_loaded_0
#define HAVE_nbif_pre_loaded_0
	.global	nbif_pre_loaded_0
nbif_pre_loaded_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(pre_loaded_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_pre_loaded_0, .-nbif_pre_loaded_0
	.type	nbif_pre_loaded_0, %function
#endif

#ifndef HAVE_nbif_process_flag_2
#define HAVE_nbif_process_flag_2
	.global	nbif_process_flag_2
nbif_process_flag_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(process_flag_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_process_flag_2, .-nbif_process_flag_2
	.type	nbif_process_flag_2, %function
#endif

#ifndef HAVE_nbif_process_flag_3
#define HAVE_nbif_process_flag_3
	.global	nbif_process_flag_3
nbif_process_flag_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(process_flag_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_process_flag_3, .-nbif_process_flag_3
	.type	nbif_process_flag_3, %function
#endif

#ifndef HAVE_nbif_process_info_1
#define HAVE_nbif_process_info_1
	.global	nbif_process_info_1
nbif_process_info_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(process_info_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_process_info_1, .-nbif_process_info_1
	.type	nbif_process_info_1, %function
#endif

#ifndef HAVE_nbif_process_info_2
#define HAVE_nbif_process_info_2
	.global	nbif_process_info_2
nbif_process_info_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(process_info_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_process_info_2, .-nbif_process_info_2
	.type	nbif_process_info_2, %function
#endif

#ifndef HAVE_nbif_processes_0
#define HAVE_nbif_processes_0
	.global	nbif_processes_0
nbif_processes_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(processes_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_processes_0, .-nbif_processes_0
	.type	nbif_processes_0, %function
#endif

#ifndef HAVE_nbif_purge_module_1
#define HAVE_nbif_purge_module_1
	.global	nbif_purge_module_1
nbif_purge_module_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(purge_module_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_purge_module_1, .-nbif_purge_module_1
	.type	nbif_purge_module_1, %function
#endif

#ifndef HAVE_nbif_put_2
#define HAVE_nbif_put_2
	.global	nbif_put_2
nbif_put_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(put_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_put_2, .-nbif_put_2
	.type	nbif_put_2, %function
#endif

#ifndef HAVE_nbif_register_2
#define HAVE_nbif_register_2
	.global	nbif_register_2
nbif_register_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(register_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_register_2, .-nbif_register_2
	.type	nbif_register_2, %function
#endif

#ifndef HAVE_nbif_registered_0
#define HAVE_nbif_registered_0
	.global	nbif_registered_0
nbif_registered_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(registered_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_registered_0, .-nbif_registered_0
	.type	nbif_registered_0, %function
#endif

#ifndef HAVE_nbif_round_1
#define HAVE_nbif_round_1
	.global	nbif_round_1
nbif_round_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(round_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_round_1, .-nbif_round_1
	.type	nbif_round_1, %function
#endif

#ifndef HAVE_nbif_self_0
#define HAVE_nbif_self_0
	.global	nbif_self_0
nbif_self_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(self_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_self_0, .-nbif_self_0
	.type	nbif_self_0, %function
#endif

#ifndef HAVE_nbif_setelement_3
#define HAVE_nbif_setelement_3
	.global	nbif_setelement_3
nbif_setelement_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(setelement_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_setelement_3, .-nbif_setelement_3
	.type	nbif_setelement_3, %function
#endif

#ifndef HAVE_nbif_size_1
#define HAVE_nbif_size_1
	.global	nbif_size_1
nbif_size_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(size_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_size_1, .-nbif_size_1
	.type	nbif_size_1, %function
#endif

#ifndef HAVE_nbif_spawn_3
#define HAVE_nbif_spawn_3
	.global	nbif_spawn_3
nbif_spawn_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(spawn_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_spawn_3, .-nbif_spawn_3
	.type	nbif_spawn_3, %function
#endif

#ifndef HAVE_nbif_spawn_link_3
#define HAVE_nbif_spawn_link_3
	.global	nbif_spawn_link_3
nbif_spawn_link_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(spawn_link_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_spawn_link_3, .-nbif_spawn_link_3
	.type	nbif_spawn_link_3, %function
#endif

#ifndef HAVE_nbif_split_binary_2
#define HAVE_nbif_split_binary_2
	.global	nbif_split_binary_2
nbif_split_binary_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(split_binary_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_split_binary_2, .-nbif_split_binary_2
	.type	nbif_split_binary_2, %function
#endif

#ifndef HAVE_nbif_statistics_1
#define HAVE_nbif_statistics_1
	.global	nbif_statistics_1
nbif_statistics_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(statistics_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_statistics_1, .-nbif_statistics_1
	.type	nbif_statistics_1, %function
#endif

#ifndef HAVE_nbif_term_to_binary_1
#define HAVE_nbif_term_to_binary_1
	.global	nbif_term_to_binary_1
nbif_term_to_binary_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_wrapper_term_to_binary_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_term_to_binary_1, .-nbif_term_to_binary_1
	.type	nbif_term_to_binary_1, %function
#endif

#ifndef HAVE_nbif_term_to_binary_2
#define HAVE_nbif_term_to_binary_2
	.global	nbif_term_to_binary_2
nbif_term_to_binary_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_wrapper_term_to_binary_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_term_to_binary_2, .-nbif_term_to_binary_2
	.type	nbif_term_to_binary_2, %function
#endif

#ifndef HAVE_nbif_throw_1
#define HAVE_nbif_throw_1
	.global	nbif_throw_1
nbif_throw_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(throw_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_throw_1, .-nbif_throw_1
	.type	nbif_throw_1, %function
#endif

#ifndef HAVE_nbif_time_0
#define HAVE_nbif_time_0
	.global	nbif_time_0
nbif_time_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(time_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_time_0, .-nbif_time_0
	.type	nbif_time_0, %function
#endif

#ifndef HAVE_nbif_tl_1
#define HAVE_nbif_tl_1
	.global	nbif_tl_1
nbif_tl_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(tl_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_tl_1, .-nbif_tl_1
	.type	nbif_tl_1, %function
#endif

#ifndef HAVE_nbif_trunc_1
#define HAVE_nbif_trunc_1
	.global	nbif_trunc_1
nbif_trunc_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(trunc_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_trunc_1, .-nbif_trunc_1
	.type	nbif_trunc_1, %function
#endif

#ifndef HAVE_nbif_tuple_to_list_1
#define HAVE_nbif_tuple_to_list_1
	.global	nbif_tuple_to_list_1
nbif_tuple_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(tuple_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_tuple_to_list_1, .-nbif_tuple_to_list_1
	.type	nbif_tuple_to_list_1, %function
#endif

#ifndef HAVE_nbif_universaltime_0
#define HAVE_nbif_universaltime_0
	.global	nbif_universaltime_0
nbif_universaltime_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(universaltime_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_universaltime_0, .-nbif_universaltime_0
	.type	nbif_universaltime_0, %function
#endif

#ifndef HAVE_nbif_universaltime_to_localtime_1
#define HAVE_nbif_universaltime_to_localtime_1
	.global	nbif_universaltime_to_localtime_1
nbif_universaltime_to_localtime_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(universaltime_to_localtime_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_universaltime_to_localtime_1, .-nbif_universaltime_to_localtime_1
	.type	nbif_universaltime_to_localtime_1, %function
#endif

#ifndef HAVE_nbif_unlink_1
#define HAVE_nbif_unlink_1
	.global	nbif_unlink_1
nbif_unlink_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(unlink_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_unlink_1, .-nbif_unlink_1
	.type	nbif_unlink_1, %function
#endif

#ifndef HAVE_nbif_unregister_1
#define HAVE_nbif_unregister_1
	.global	nbif_unregister_1
nbif_unregister_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(unregister_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_unregister_1, .-nbif_unregister_1
	.type	nbif_unregister_1, %function
#endif

#ifndef HAVE_nbif_whereis_1
#define HAVE_nbif_whereis_1
	.global	nbif_whereis_1
nbif_whereis_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(whereis_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_whereis_1, .-nbif_whereis_1
	.type	nbif_whereis_1, %function
#endif

#ifndef HAVE_nbif_spawn_opt_1
#define HAVE_nbif_spawn_opt_1
	.global	nbif_spawn_opt_1
nbif_spawn_opt_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(spawn_opt_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_spawn_opt_1, .-nbif_spawn_opt_1
	.type	nbif_spawn_opt_1, %function
#endif

#ifndef HAVE_nbif_setnode_2
#define HAVE_nbif_setnode_2
	.global	nbif_setnode_2
nbif_setnode_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(setnode_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_setnode_2, .-nbif_setnode_2
	.type	nbif_setnode_2, %function
#endif

#ifndef HAVE_nbif_setnode_3
#define HAVE_nbif_setnode_3
	.global	nbif_setnode_3
nbif_setnode_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(setnode_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_setnode_3, .-nbif_setnode_3
	.type	nbif_setnode_3, %function
#endif

#ifndef HAVE_nbif_dist_exit_3
#define HAVE_nbif_dist_exit_3
	.global	nbif_dist_exit_3
nbif_dist_exit_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(dist_exit_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_dist_exit_3, .-nbif_dist_exit_3
	.type	nbif_dist_exit_3, %function
#endif

#ifndef HAVE_nbif_erts_internal_port_info_1
#define HAVE_nbif_erts_internal_port_info_1
	.global	nbif_erts_internal_port_info_1
nbif_erts_internal_port_info_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_internal_port_info_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erts_internal_port_info_1, .-nbif_erts_internal_port_info_1
	.type	nbif_erts_internal_port_info_1, %function
#endif

#ifndef HAVE_nbif_erts_internal_port_info_2
#define HAVE_nbif_erts_internal_port_info_2
	.global	nbif_erts_internal_port_info_2
nbif_erts_internal_port_info_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_internal_port_info_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_internal_port_info_2, .-nbif_erts_internal_port_info_2
	.type	nbif_erts_internal_port_info_2, %function
#endif

#ifndef HAVE_nbif_erts_internal_port_call_3
#define HAVE_nbif_erts_internal_port_call_3
	.global	nbif_erts_internal_port_call_3
nbif_erts_internal_port_call_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_internal_port_call_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_internal_port_call_3, .-nbif_erts_internal_port_call_3
	.type	nbif_erts_internal_port_call_3, %function
#endif

#ifndef HAVE_nbif_erts_internal_port_command_3
#define HAVE_nbif_erts_internal_port_command_3
	.global	nbif_erts_internal_port_command_3
nbif_erts_internal_port_command_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_internal_port_command_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_internal_port_command_3, .-nbif_erts_internal_port_command_3
	.type	nbif_erts_internal_port_command_3, %function
#endif

#ifndef HAVE_nbif_erts_internal_port_control_3
#define HAVE_nbif_erts_internal_port_control_3
	.global	nbif_erts_internal_port_control_3
nbif_erts_internal_port_control_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_internal_port_control_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_internal_port_control_3, .-nbif_erts_internal_port_control_3
	.type	nbif_erts_internal_port_control_3, %function
#endif

#ifndef HAVE_nbif_erts_internal_port_close_1
#define HAVE_nbif_erts_internal_port_close_1
	.global	nbif_erts_internal_port_close_1
nbif_erts_internal_port_close_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_internal_port_close_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erts_internal_port_close_1, .-nbif_erts_internal_port_close_1
	.type	nbif_erts_internal_port_close_1, %function
#endif

#ifndef HAVE_nbif_erts_internal_port_connect_2
#define HAVE_nbif_erts_internal_port_connect_2
	.global	nbif_erts_internal_port_connect_2
nbif_erts_internal_port_connect_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_internal_port_connect_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_internal_port_connect_2, .-nbif_erts_internal_port_connect_2
	.type	nbif_erts_internal_port_connect_2, %function
#endif

#ifndef HAVE_nbif_erts_internal_request_system_task_3
#define HAVE_nbif_erts_internal_request_system_task_3
	.global	nbif_erts_internal_request_system_task_3
nbif_erts_internal_request_system_task_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_internal_request_system_task_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_internal_request_system_task_3, .-nbif_erts_internal_request_system_task_3
	.type	nbif_erts_internal_request_system_task_3, %function
#endif

#ifndef HAVE_nbif_erts_internal_check_process_code_2
#define HAVE_nbif_erts_internal_check_process_code_2
	.global	nbif_erts_internal_check_process_code_2
nbif_erts_internal_check_process_code_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_internal_check_process_code_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_internal_check_process_code_2, .-nbif_erts_internal_check_process_code_2
	.type	nbif_erts_internal_check_process_code_2, %function
#endif

#ifndef HAVE_nbif_erts_internal_map_to_tuple_keys_1
#define HAVE_nbif_erts_internal_map_to_tuple_keys_1
	.global	nbif_erts_internal_map_to_tuple_keys_1
nbif_erts_internal_map_to_tuple_keys_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_internal_map_to_tuple_keys_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erts_internal_map_to_tuple_keys_1, .-nbif_erts_internal_map_to_tuple_keys_1
	.type	nbif_erts_internal_map_to_tuple_keys_1, %function
#endif

#ifndef HAVE_nbif_port_set_data_2
#define HAVE_nbif_port_set_data_2
	.global	nbif_port_set_data_2
nbif_port_set_data_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(port_set_data_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_port_set_data_2, .-nbif_port_set_data_2
	.type	nbif_port_set_data_2, %function
#endif

#ifndef HAVE_nbif_port_get_data_1
#define HAVE_nbif_port_get_data_1
	.global	nbif_port_get_data_1
nbif_port_get_data_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(port_get_data_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_port_get_data_1, .-nbif_port_get_data_1
	.type	nbif_port_get_data_1, %function
#endif

#ifndef HAVE_nbif_trace_pattern_2
#define HAVE_nbif_trace_pattern_2
	.global	nbif_trace_pattern_2
nbif_trace_pattern_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(trace_pattern_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_trace_pattern_2, .-nbif_trace_pattern_2
	.type	nbif_trace_pattern_2, %function
#endif

#ifndef HAVE_nbif_trace_pattern_3
#define HAVE_nbif_trace_pattern_3
	.global	nbif_trace_pattern_3
nbif_trace_pattern_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(trace_pattern_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_trace_pattern_3, .-nbif_trace_pattern_3
	.type	nbif_trace_pattern_3, %function
#endif

#ifndef HAVE_nbif_trace_3
#define HAVE_nbif_trace_3
	.global	nbif_trace_3
nbif_trace_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(trace_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_trace_3, .-nbif_trace_3
	.type	nbif_trace_3, %function
#endif

#ifndef HAVE_nbif_trace_info_2
#define HAVE_nbif_trace_info_2
	.global	nbif_trace_info_2
nbif_trace_info_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(trace_info_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_trace_info_2, .-nbif_trace_info_2
	.type	nbif_trace_info_2, %function
#endif

#ifndef HAVE_nbif_trace_delivered_1
#define HAVE_nbif_trace_delivered_1
	.global	nbif_trace_delivered_1
nbif_trace_delivered_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(trace_delivered_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_trace_delivered_1, .-nbif_trace_delivered_1
	.type	nbif_trace_delivered_1, %function
#endif

#ifndef HAVE_nbif_seq_trace_2
#define HAVE_nbif_seq_trace_2
	.global	nbif_seq_trace_2
nbif_seq_trace_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(seq_trace_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_seq_trace_2, .-nbif_seq_trace_2
	.type	nbif_seq_trace_2, %function
#endif

#ifndef HAVE_nbif_seq_trace_info_1
#define HAVE_nbif_seq_trace_info_1
	.global	nbif_seq_trace_info_1
nbif_seq_trace_info_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(seq_trace_info_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_seq_trace_info_1, .-nbif_seq_trace_info_1
	.type	nbif_seq_trace_info_1, %function
#endif

#ifndef HAVE_nbif_seq_trace_print_1
#define HAVE_nbif_seq_trace_print_1
	.global	nbif_seq_trace_print_1
nbif_seq_trace_print_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(seq_trace_print_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_seq_trace_print_1, .-nbif_seq_trace_print_1
	.type	nbif_seq_trace_print_1, %function
#endif

#ifndef HAVE_nbif_seq_trace_print_2
#define HAVE_nbif_seq_trace_print_2
	.global	nbif_seq_trace_print_2
nbif_seq_trace_print_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(seq_trace_print_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_seq_trace_print_2, .-nbif_seq_trace_print_2
	.type	nbif_seq_trace_print_2, %function
#endif

#ifndef HAVE_nbif_suspend_process_2
#define HAVE_nbif_suspend_process_2
	.global	nbif_suspend_process_2
nbif_suspend_process_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(suspend_process_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_suspend_process_2, .-nbif_suspend_process_2
	.type	nbif_suspend_process_2, %function
#endif

#ifndef HAVE_nbif_resume_process_1
#define HAVE_nbif_resume_process_1
	.global	nbif_resume_process_1
nbif_resume_process_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(resume_process_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_resume_process_1, .-nbif_resume_process_1
	.type	nbif_resume_process_1, %function
#endif

#ifndef HAVE_nbif_process_display_2
#define HAVE_nbif_process_display_2
	.global	nbif_process_display_2
nbif_process_display_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(process_display_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_process_display_2, .-nbif_process_display_2
	.type	nbif_process_display_2, %function
#endif

#ifndef HAVE_nbif_bump_reductions_1
#define HAVE_nbif_bump_reductions_1
	.global	nbif_bump_reductions_1
nbif_bump_reductions_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(bump_reductions_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_bump_reductions_1, .-nbif_bump_reductions_1
	.type	nbif_bump_reductions_1, %function
#endif

#ifndef HAVE_nbif_math_cos_1
#define HAVE_nbif_math_cos_1
	.global	nbif_math_cos_1
nbif_math_cos_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_cos_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_cos_1, .-nbif_math_cos_1
	.type	nbif_math_cos_1, %function
#endif

#ifndef HAVE_nbif_math_cosh_1
#define HAVE_nbif_math_cosh_1
	.global	nbif_math_cosh_1
nbif_math_cosh_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_cosh_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_cosh_1, .-nbif_math_cosh_1
	.type	nbif_math_cosh_1, %function
#endif

#ifndef HAVE_nbif_math_sin_1
#define HAVE_nbif_math_sin_1
	.global	nbif_math_sin_1
nbif_math_sin_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_sin_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_sin_1, .-nbif_math_sin_1
	.type	nbif_math_sin_1, %function
#endif

#ifndef HAVE_nbif_math_sinh_1
#define HAVE_nbif_math_sinh_1
	.global	nbif_math_sinh_1
nbif_math_sinh_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_sinh_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_sinh_1, .-nbif_math_sinh_1
	.type	nbif_math_sinh_1, %function
#endif

#ifndef HAVE_nbif_math_tan_1
#define HAVE_nbif_math_tan_1
	.global	nbif_math_tan_1
nbif_math_tan_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_tan_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_tan_1, .-nbif_math_tan_1
	.type	nbif_math_tan_1, %function
#endif

#ifndef HAVE_nbif_math_tanh_1
#define HAVE_nbif_math_tanh_1
	.global	nbif_math_tanh_1
nbif_math_tanh_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_tanh_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_tanh_1, .-nbif_math_tanh_1
	.type	nbif_math_tanh_1, %function
#endif

#ifndef HAVE_nbif_math_acos_1
#define HAVE_nbif_math_acos_1
	.global	nbif_math_acos_1
nbif_math_acos_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_acos_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_acos_1, .-nbif_math_acos_1
	.type	nbif_math_acos_1, %function
#endif

#ifndef HAVE_nbif_math_acosh_1
#define HAVE_nbif_math_acosh_1
	.global	nbif_math_acosh_1
nbif_math_acosh_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_acosh_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_acosh_1, .-nbif_math_acosh_1
	.type	nbif_math_acosh_1, %function
#endif

#ifndef HAVE_nbif_math_asin_1
#define HAVE_nbif_math_asin_1
	.global	nbif_math_asin_1
nbif_math_asin_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_asin_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_asin_1, .-nbif_math_asin_1
	.type	nbif_math_asin_1, %function
#endif

#ifndef HAVE_nbif_math_asinh_1
#define HAVE_nbif_math_asinh_1
	.global	nbif_math_asinh_1
nbif_math_asinh_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_asinh_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_asinh_1, .-nbif_math_asinh_1
	.type	nbif_math_asinh_1, %function
#endif

#ifndef HAVE_nbif_math_atan_1
#define HAVE_nbif_math_atan_1
	.global	nbif_math_atan_1
nbif_math_atan_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_atan_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_atan_1, .-nbif_math_atan_1
	.type	nbif_math_atan_1, %function
#endif

#ifndef HAVE_nbif_math_atanh_1
#define HAVE_nbif_math_atanh_1
	.global	nbif_math_atanh_1
nbif_math_atanh_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_atanh_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_atanh_1, .-nbif_math_atanh_1
	.type	nbif_math_atanh_1, %function
#endif

#ifndef HAVE_nbif_math_erf_1
#define HAVE_nbif_math_erf_1
	.global	nbif_math_erf_1
nbif_math_erf_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_erf_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_erf_1, .-nbif_math_erf_1
	.type	nbif_math_erf_1, %function
#endif

#ifndef HAVE_nbif_math_erfc_1
#define HAVE_nbif_math_erfc_1
	.global	nbif_math_erfc_1
nbif_math_erfc_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_erfc_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_erfc_1, .-nbif_math_erfc_1
	.type	nbif_math_erfc_1, %function
#endif

#ifndef HAVE_nbif_math_exp_1
#define HAVE_nbif_math_exp_1
	.global	nbif_math_exp_1
nbif_math_exp_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_exp_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_exp_1, .-nbif_math_exp_1
	.type	nbif_math_exp_1, %function
#endif

#ifndef HAVE_nbif_math_log_1
#define HAVE_nbif_math_log_1
	.global	nbif_math_log_1
nbif_math_log_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_log_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_log_1, .-nbif_math_log_1
	.type	nbif_math_log_1, %function
#endif

#ifndef HAVE_nbif_math_log10_1
#define HAVE_nbif_math_log10_1
	.global	nbif_math_log10_1
nbif_math_log10_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_log10_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_log10_1, .-nbif_math_log10_1
	.type	nbif_math_log10_1, %function
#endif

#ifndef HAVE_nbif_math_sqrt_1
#define HAVE_nbif_math_sqrt_1
	.global	nbif_math_sqrt_1
nbif_math_sqrt_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(math_sqrt_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_math_sqrt_1, .-nbif_math_sqrt_1
	.type	nbif_math_sqrt_1, %function
#endif

#ifndef HAVE_nbif_math_atan2_2
#define HAVE_nbif_math_atan2_2
	.global	nbif_math_atan2_2
nbif_math_atan2_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(math_atan2_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_math_atan2_2, .-nbif_math_atan2_2
	.type	nbif_math_atan2_2, %function
#endif

#ifndef HAVE_nbif_math_pow_2
#define HAVE_nbif_math_pow_2
	.global	nbif_math_pow_2
nbif_math_pow_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(math_pow_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_math_pow_2, .-nbif_math_pow_2
	.type	nbif_math_pow_2, %function
#endif

#ifndef HAVE_nbif_start_timer_3
#define HAVE_nbif_start_timer_3
	.global	nbif_start_timer_3
nbif_start_timer_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(start_timer_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_start_timer_3, .-nbif_start_timer_3
	.type	nbif_start_timer_3, %function
#endif

#ifndef HAVE_nbif_send_after_3
#define HAVE_nbif_send_after_3
	.global	nbif_send_after_3
nbif_send_after_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(send_after_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_send_after_3, .-nbif_send_after_3
	.type	nbif_send_after_3, %function
#endif

#ifndef HAVE_nbif_cancel_timer_1
#define HAVE_nbif_cancel_timer_1
	.global	nbif_cancel_timer_1
nbif_cancel_timer_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(cancel_timer_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_cancel_timer_1, .-nbif_cancel_timer_1
	.type	nbif_cancel_timer_1, %function
#endif

#ifndef HAVE_nbif_read_timer_1
#define HAVE_nbif_read_timer_1
	.global	nbif_read_timer_1
nbif_read_timer_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(read_timer_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_read_timer_1, .-nbif_read_timer_1
	.type	nbif_read_timer_1, %function
#endif

#ifndef HAVE_nbif_make_tuple_2
#define HAVE_nbif_make_tuple_2
	.global	nbif_make_tuple_2
nbif_make_tuple_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(make_tuple_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_make_tuple_2, .-nbif_make_tuple_2
	.type	nbif_make_tuple_2, %function
#endif

#ifndef HAVE_nbif_append_element_2
#define HAVE_nbif_append_element_2
	.global	nbif_append_element_2
nbif_append_element_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(append_element_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_append_element_2, .-nbif_append_element_2
	.type	nbif_append_element_2, %function
#endif

#ifndef HAVE_nbif_make_tuple_3
#define HAVE_nbif_make_tuple_3
	.global	nbif_make_tuple_3
nbif_make_tuple_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(make_tuple_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_make_tuple_3, .-nbif_make_tuple_3
	.type	nbif_make_tuple_3, %function
#endif

#ifndef HAVE_nbif_system_flag_2
#define HAVE_nbif_system_flag_2
	.global	nbif_system_flag_2
nbif_system_flag_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(system_flag_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_system_flag_2, .-nbif_system_flag_2
	.type	nbif_system_flag_2, %function
#endif

#ifndef HAVE_nbif_system_info_1
#define HAVE_nbif_system_info_1
	.global	nbif_system_info_1
nbif_system_info_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(system_info_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_system_info_1, .-nbif_system_info_1
	.type	nbif_system_info_1, %function
#endif

#ifndef HAVE_nbif_system_monitor_0
#define HAVE_nbif_system_monitor_0
	.global	nbif_system_monitor_0
nbif_system_monitor_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(system_monitor_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_system_monitor_0, .-nbif_system_monitor_0
	.type	nbif_system_monitor_0, %function
#endif

#ifndef HAVE_nbif_system_monitor_1
#define HAVE_nbif_system_monitor_1
	.global	nbif_system_monitor_1
nbif_system_monitor_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(system_monitor_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_system_monitor_1, .-nbif_system_monitor_1
	.type	nbif_system_monitor_1, %function
#endif

#ifndef HAVE_nbif_system_monitor_2
#define HAVE_nbif_system_monitor_2
	.global	nbif_system_monitor_2
nbif_system_monitor_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(system_monitor_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_system_monitor_2, .-nbif_system_monitor_2
	.type	nbif_system_monitor_2, %function
#endif

#ifndef HAVE_nbif_system_profile_2
#define HAVE_nbif_system_profile_2
	.global	nbif_system_profile_2
nbif_system_profile_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(system_profile_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_system_profile_2, .-nbif_system_profile_2
	.type	nbif_system_profile_2, %function
#endif

#ifndef HAVE_nbif_system_profile_0
#define HAVE_nbif_system_profile_0
	.global	nbif_system_profile_0
nbif_system_profile_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(system_profile_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_system_profile_0, .-nbif_system_profile_0
	.type	nbif_system_profile_0, %function
#endif

#ifndef HAVE_nbif_ref_to_list_1
#define HAVE_nbif_ref_to_list_1
	.global	nbif_ref_to_list_1
nbif_ref_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ref_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ref_to_list_1, .-nbif_ref_to_list_1
	.type	nbif_ref_to_list_1, %function
#endif

#ifndef HAVE_nbif_port_to_list_1
#define HAVE_nbif_port_to_list_1
	.global	nbif_port_to_list_1
nbif_port_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(port_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_port_to_list_1, .-nbif_port_to_list_1
	.type	nbif_port_to_list_1, %function
#endif

#ifndef HAVE_nbif_fun_to_list_1
#define HAVE_nbif_fun_to_list_1
	.global	nbif_fun_to_list_1
nbif_fun_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(fun_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_fun_to_list_1, .-nbif_fun_to_list_1
	.type	nbif_fun_to_list_1, %function
#endif

#ifndef HAVE_nbif_monitor_2
#define HAVE_nbif_monitor_2
	.global	nbif_monitor_2
nbif_monitor_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(monitor_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_monitor_2, .-nbif_monitor_2
	.type	nbif_monitor_2, %function
#endif

#ifndef HAVE_nbif_demonitor_1
#define HAVE_nbif_demonitor_1
	.global	nbif_demonitor_1
nbif_demonitor_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(demonitor_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_demonitor_1, .-nbif_demonitor_1
	.type	nbif_demonitor_1, %function
#endif

#ifndef HAVE_nbif_demonitor_2
#define HAVE_nbif_demonitor_2
	.global	nbif_demonitor_2
nbif_demonitor_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(demonitor_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_demonitor_2, .-nbif_demonitor_2
	.type	nbif_demonitor_2, %function
#endif

#ifndef HAVE_nbif_is_process_alive_1
#define HAVE_nbif_is_process_alive_1
	.global	nbif_is_process_alive_1
nbif_is_process_alive_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_process_alive_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_process_alive_1, .-nbif_is_process_alive_1
	.type	nbif_is_process_alive_1, %function
#endif

#ifndef HAVE_nbif_error_1
#define HAVE_nbif_error_1
	.global	nbif_error_1
nbif_error_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(error_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_error_1, .-nbif_error_1
	.type	nbif_error_1, %function
#endif

#ifndef HAVE_nbif_error_2
#define HAVE_nbif_error_2
	.global	nbif_error_2
nbif_error_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(error_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_error_2, .-nbif_error_2
	.type	nbif_error_2, %function
#endif

#ifndef HAVE_nbif_raise_3
#define HAVE_nbif_raise_3
	.global	nbif_raise_3
nbif_raise_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(raise_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_raise_3, .-nbif_raise_3
	.type	nbif_raise_3, %function
#endif

#ifndef HAVE_nbif_get_stacktrace_0
#define HAVE_nbif_get_stacktrace_0
	.global	nbif_get_stacktrace_0
nbif_get_stacktrace_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(get_stacktrace_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_get_stacktrace_0, .-nbif_get_stacktrace_0
	.type	nbif_get_stacktrace_0, %function
#endif

#ifndef HAVE_nbif_is_builtin_3
#define HAVE_nbif_is_builtin_3
	.global	nbif_is_builtin_3
nbif_is_builtin_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(is_builtin_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_is_builtin_3, .-nbif_is_builtin_3
	.type	nbif_is_builtin_3, %function
#endif

#ifndef HAVE_nbif_and_2
#define HAVE_nbif_and_2
	.global	nbif_and_2
nbif_and_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(and_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_and_2, .-nbif_and_2
	.type	nbif_and_2, %function
#endif

#ifndef HAVE_nbif_or_2
#define HAVE_nbif_or_2
	.global	nbif_or_2
nbif_or_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(or_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_or_2, .-nbif_or_2
	.type	nbif_or_2, %function
#endif

#ifndef HAVE_nbif_xor_2
#define HAVE_nbif_xor_2
	.global	nbif_xor_2
nbif_xor_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(xor_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_xor_2, .-nbif_xor_2
	.type	nbif_xor_2, %function
#endif

#ifndef HAVE_nbif_not_1
#define HAVE_nbif_not_1
	.global	nbif_not_1
nbif_not_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(not_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_not_1, .-nbif_not_1
	.type	nbif_not_1, %function
#endif

#ifndef HAVE_nbif_sgt_2
#define HAVE_nbif_sgt_2
	.global	nbif_sgt_2
nbif_sgt_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(sgt_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_sgt_2, .-nbif_sgt_2
	.type	nbif_sgt_2, %function
#endif

#ifndef HAVE_nbif_sge_2
#define HAVE_nbif_sge_2
	.global	nbif_sge_2
nbif_sge_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(sge_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_sge_2, .-nbif_sge_2
	.type	nbif_sge_2, %function
#endif

#ifndef HAVE_nbif_slt_2
#define HAVE_nbif_slt_2
	.global	nbif_slt_2
nbif_slt_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(slt_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_slt_2, .-nbif_slt_2
	.type	nbif_slt_2, %function
#endif

#ifndef HAVE_nbif_sle_2
#define HAVE_nbif_sle_2
	.global	nbif_sle_2
nbif_sle_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(sle_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_sle_2, .-nbif_sle_2
	.type	nbif_sle_2, %function
#endif

#ifndef HAVE_nbif_seq_2
#define HAVE_nbif_seq_2
	.global	nbif_seq_2
nbif_seq_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(seq_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_seq_2, .-nbif_seq_2
	.type	nbif_seq_2, %function
#endif

#ifndef HAVE_nbif_seqeq_2
#define HAVE_nbif_seqeq_2
	.global	nbif_seqeq_2
nbif_seqeq_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(seqeq_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_seqeq_2, .-nbif_seqeq_2
	.type	nbif_seqeq_2, %function
#endif

#ifndef HAVE_nbif_sneq_2
#define HAVE_nbif_sneq_2
	.global	nbif_sneq_2
nbif_sneq_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(sneq_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_sneq_2, .-nbif_sneq_2
	.type	nbif_sneq_2, %function
#endif

#ifndef HAVE_nbif_sneqeq_2
#define HAVE_nbif_sneqeq_2
	.global	nbif_sneqeq_2
nbif_sneqeq_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(sneqeq_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_sneqeq_2, .-nbif_sneqeq_2
	.type	nbif_sneqeq_2, %function
#endif

#ifndef HAVE_nbif_splus_2
#define HAVE_nbif_splus_2
	.global	nbif_splus_2
nbif_splus_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(splus_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_splus_2, .-nbif_splus_2
	.type	nbif_splus_2, %function
#endif

#ifndef HAVE_nbif_sminus_2
#define HAVE_nbif_sminus_2
	.global	nbif_sminus_2
nbif_sminus_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(sminus_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_sminus_2, .-nbif_sminus_2
	.type	nbif_sminus_2, %function
#endif

#ifndef HAVE_nbif_stimes_2
#define HAVE_nbif_stimes_2
	.global	nbif_stimes_2
nbif_stimes_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(stimes_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_stimes_2, .-nbif_stimes_2
	.type	nbif_stimes_2, %function
#endif

#ifndef HAVE_nbif_div_2
#define HAVE_nbif_div_2
	.global	nbif_div_2
nbif_div_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(div_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_div_2, .-nbif_div_2
	.type	nbif_div_2, %function
#endif

#ifndef HAVE_nbif_intdiv_2
#define HAVE_nbif_intdiv_2
	.global	nbif_intdiv_2
nbif_intdiv_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(intdiv_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_intdiv_2, .-nbif_intdiv_2
	.type	nbif_intdiv_2, %function
#endif

#ifndef HAVE_nbif_rem_2
#define HAVE_nbif_rem_2
	.global	nbif_rem_2
nbif_rem_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(rem_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_rem_2, .-nbif_rem_2
	.type	nbif_rem_2, %function
#endif

#ifndef HAVE_nbif_bor_2
#define HAVE_nbif_bor_2
	.global	nbif_bor_2
nbif_bor_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(bor_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_bor_2, .-nbif_bor_2
	.type	nbif_bor_2, %function
#endif

#ifndef HAVE_nbif_band_2
#define HAVE_nbif_band_2
	.global	nbif_band_2
nbif_band_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(band_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_band_2, .-nbif_band_2
	.type	nbif_band_2, %function
#endif

#ifndef HAVE_nbif_bxor_2
#define HAVE_nbif_bxor_2
	.global	nbif_bxor_2
nbif_bxor_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(bxor_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_bxor_2, .-nbif_bxor_2
	.type	nbif_bxor_2, %function
#endif

#ifndef HAVE_nbif_bsl_2
#define HAVE_nbif_bsl_2
	.global	nbif_bsl_2
nbif_bsl_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(bsl_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_bsl_2, .-nbif_bsl_2
	.type	nbif_bsl_2, %function
#endif

#ifndef HAVE_nbif_bsr_2
#define HAVE_nbif_bsr_2
	.global	nbif_bsr_2
nbif_bsr_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(bsr_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_bsr_2, .-nbif_bsr_2
	.type	nbif_bsr_2, %function
#endif

#ifndef HAVE_nbif_bnot_1
#define HAVE_nbif_bnot_1
	.global	nbif_bnot_1
nbif_bnot_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(bnot_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_bnot_1, .-nbif_bnot_1
	.type	nbif_bnot_1, %function
#endif

#ifndef HAVE_nbif_sminus_1
#define HAVE_nbif_sminus_1
	.global	nbif_sminus_1
nbif_sminus_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(sminus_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_sminus_1, .-nbif_sminus_1
	.type	nbif_sminus_1, %function
#endif

#ifndef HAVE_nbif_splus_1
#define HAVE_nbif_splus_1
	.global	nbif_splus_1
nbif_splus_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(splus_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_splus_1, .-nbif_splus_1
	.type	nbif_splus_1, %function
#endif

#ifndef HAVE_nbif_ebif_bang_2
#define HAVE_nbif_ebif_bang_2
	.global	nbif_ebif_bang_2
nbif_ebif_bang_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ebif_bang_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ebif_bang_2, .-nbif_ebif_bang_2
	.type	nbif_ebif_bang_2, %function
#endif

#ifndef HAVE_nbif_send_2
#define HAVE_nbif_send_2
	.global	nbif_send_2
nbif_send_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(send_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_send_2, .-nbif_send_2
	.type	nbif_send_2, %function
#endif

#ifndef HAVE_nbif_send_3
#define HAVE_nbif_send_3
	.global	nbif_send_3
nbif_send_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(send_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_send_3, .-nbif_send_3
	.type	nbif_send_3, %function
#endif

#ifndef HAVE_nbif_ebif_plusplus_2
#define HAVE_nbif_ebif_plusplus_2
	.global	nbif_ebif_plusplus_2
nbif_ebif_plusplus_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ebif_plusplus_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ebif_plusplus_2, .-nbif_ebif_plusplus_2
	.type	nbif_ebif_plusplus_2, %function
#endif

#ifndef HAVE_nbif_append_2
#define HAVE_nbif_append_2
	.global	nbif_append_2
nbif_append_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(append_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_append_2, .-nbif_append_2
	.type	nbif_append_2, %function
#endif

#ifndef HAVE_nbif_ebif_minusminus_2
#define HAVE_nbif_ebif_minusminus_2
	.global	nbif_ebif_minusminus_2
nbif_ebif_minusminus_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ebif_minusminus_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ebif_minusminus_2, .-nbif_ebif_minusminus_2
	.type	nbif_ebif_minusminus_2, %function
#endif

#ifndef HAVE_nbif_subtract_2
#define HAVE_nbif_subtract_2
	.global	nbif_subtract_2
nbif_subtract_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(subtract_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_subtract_2, .-nbif_subtract_2
	.type	nbif_subtract_2, %function
#endif

#ifndef HAVE_nbif_is_atom_1
#define HAVE_nbif_is_atom_1
	.global	nbif_is_atom_1
nbif_is_atom_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_atom_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_atom_1, .-nbif_is_atom_1
	.type	nbif_is_atom_1, %function
#endif

#ifndef HAVE_nbif_is_list_1
#define HAVE_nbif_is_list_1
	.global	nbif_is_list_1
nbif_is_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_list_1, .-nbif_is_list_1
	.type	nbif_is_list_1, %function
#endif

#ifndef HAVE_nbif_is_tuple_1
#define HAVE_nbif_is_tuple_1
	.global	nbif_is_tuple_1
nbif_is_tuple_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_tuple_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_tuple_1, .-nbif_is_tuple_1
	.type	nbif_is_tuple_1, %function
#endif

#ifndef HAVE_nbif_is_float_1
#define HAVE_nbif_is_float_1
	.global	nbif_is_float_1
nbif_is_float_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_float_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_float_1, .-nbif_is_float_1
	.type	nbif_is_float_1, %function
#endif

#ifndef HAVE_nbif_is_integer_1
#define HAVE_nbif_is_integer_1
	.global	nbif_is_integer_1
nbif_is_integer_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_integer_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_integer_1, .-nbif_is_integer_1
	.type	nbif_is_integer_1, %function
#endif

#ifndef HAVE_nbif_is_number_1
#define HAVE_nbif_is_number_1
	.global	nbif_is_number_1
nbif_is_number_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_number_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_number_1, .-nbif_is_number_1
	.type	nbif_is_number_1, %function
#endif

#ifndef HAVE_nbif_is_pid_1
#define HAVE_nbif_is_pid_1
	.global	nbif_is_pid_1
nbif_is_pid_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_pid_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_pid_1, .-nbif_is_pid_1
	.type	nbif_is_pid_1, %function
#endif

#ifndef HAVE_nbif_is_port_1
#define HAVE_nbif_is_port_1
	.global	nbif_is_port_1
nbif_is_port_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_port_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_port_1, .-nbif_is_port_1
	.type	nbif_is_port_1, %function
#endif

#ifndef HAVE_nbif_is_reference_1
#define HAVE_nbif_is_reference_1
	.global	nbif_is_reference_1
nbif_is_reference_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_reference_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_reference_1, .-nbif_is_reference_1
	.type	nbif_is_reference_1, %function
#endif

#ifndef HAVE_nbif_is_binary_1
#define HAVE_nbif_is_binary_1
	.global	nbif_is_binary_1
nbif_is_binary_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_binary_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_binary_1, .-nbif_is_binary_1
	.type	nbif_is_binary_1, %function
#endif

#ifndef HAVE_nbif_is_function_1
#define HAVE_nbif_is_function_1
	.global	nbif_is_function_1
nbif_is_function_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_function_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_function_1, .-nbif_is_function_1
	.type	nbif_is_function_1, %function
#endif

#ifndef HAVE_nbif_is_function_2
#define HAVE_nbif_is_function_2
	.global	nbif_is_function_2
nbif_is_function_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(is_function_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_is_function_2, .-nbif_is_function_2
	.type	nbif_is_function_2, %function
#endif

#ifndef HAVE_nbif_is_record_2
#define HAVE_nbif_is_record_2
	.global	nbif_is_record_2
nbif_is_record_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(is_record_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_is_record_2, .-nbif_is_record_2
	.type	nbif_is_record_2, %function
#endif

#ifndef HAVE_nbif_is_record_3
#define HAVE_nbif_is_record_3
	.global	nbif_is_record_3
nbif_is_record_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(is_record_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_is_record_3, .-nbif_is_record_3
	.type	nbif_is_record_3, %function
#endif

#ifndef HAVE_nbif_match_spec_test_3
#define HAVE_nbif_match_spec_test_3
	.global	nbif_match_spec_test_3
nbif_match_spec_test_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(match_spec_test_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_match_spec_test_3, .-nbif_match_spec_test_3
	.type	nbif_match_spec_test_3, %function
#endif

#ifndef HAVE_nbif_ets_all_0
#define HAVE_nbif_ets_all_0
	.global	nbif_ets_all_0
nbif_ets_all_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(ets_all_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_all_0, .-nbif_ets_all_0
	.type	nbif_ets_all_0, %function
#endif

#ifndef HAVE_nbif_ets_new_2
#define HAVE_nbif_ets_new_2
	.global	nbif_ets_new_2
nbif_ets_new_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_new_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_new_2, .-nbif_ets_new_2
	.type	nbif_ets_new_2, %function
#endif

#ifndef HAVE_nbif_ets_delete_1
#define HAVE_nbif_ets_delete_1
	.global	nbif_ets_delete_1
nbif_ets_delete_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_delete_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ets_delete_1, .-nbif_ets_delete_1
	.type	nbif_ets_delete_1, %function
#endif

#ifndef HAVE_nbif_ets_delete_2
#define HAVE_nbif_ets_delete_2
	.global	nbif_ets_delete_2
nbif_ets_delete_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_delete_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_delete_2, .-nbif_ets_delete_2
	.type	nbif_ets_delete_2, %function
#endif

#ifndef HAVE_nbif_ets_delete_all_objects_1
#define HAVE_nbif_ets_delete_all_objects_1
	.global	nbif_ets_delete_all_objects_1
nbif_ets_delete_all_objects_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_delete_all_objects_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ets_delete_all_objects_1, .-nbif_ets_delete_all_objects_1
	.type	nbif_ets_delete_all_objects_1, %function
#endif

#ifndef HAVE_nbif_ets_delete_object_2
#define HAVE_nbif_ets_delete_object_2
	.global	nbif_ets_delete_object_2
nbif_ets_delete_object_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_delete_object_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_delete_object_2, .-nbif_ets_delete_object_2
	.type	nbif_ets_delete_object_2, %function
#endif

#ifndef HAVE_nbif_ets_first_1
#define HAVE_nbif_ets_first_1
	.global	nbif_ets_first_1
nbif_ets_first_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_first_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ets_first_1, .-nbif_ets_first_1
	.type	nbif_ets_first_1, %function
#endif

#ifndef HAVE_nbif_ets_is_compiled_ms_1
#define HAVE_nbif_ets_is_compiled_ms_1
	.global	nbif_ets_is_compiled_ms_1
nbif_ets_is_compiled_ms_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_is_compiled_ms_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ets_is_compiled_ms_1, .-nbif_ets_is_compiled_ms_1
	.type	nbif_ets_is_compiled_ms_1, %function
#endif

#ifndef HAVE_nbif_ets_lookup_2
#define HAVE_nbif_ets_lookup_2
	.global	nbif_ets_lookup_2
nbif_ets_lookup_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_lookup_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_lookup_2, .-nbif_ets_lookup_2
	.type	nbif_ets_lookup_2, %function
#endif

#ifndef HAVE_nbif_ets_lookup_element_3
#define HAVE_nbif_ets_lookup_element_3
	.global	nbif_ets_lookup_element_3
nbif_ets_lookup_element_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_lookup_element_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_lookup_element_3, .-nbif_ets_lookup_element_3
	.type	nbif_ets_lookup_element_3, %function
#endif

#ifndef HAVE_nbif_ets_info_1
#define HAVE_nbif_ets_info_1
	.global	nbif_ets_info_1
nbif_ets_info_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_info_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ets_info_1, .-nbif_ets_info_1
	.type	nbif_ets_info_1, %function
#endif

#ifndef HAVE_nbif_ets_info_2
#define HAVE_nbif_ets_info_2
	.global	nbif_ets_info_2
nbif_ets_info_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_info_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_info_2, .-nbif_ets_info_2
	.type	nbif_ets_info_2, %function
#endif

#ifndef HAVE_nbif_ets_last_1
#define HAVE_nbif_ets_last_1
	.global	nbif_ets_last_1
nbif_ets_last_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_last_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ets_last_1, .-nbif_ets_last_1
	.type	nbif_ets_last_1, %function
#endif

#ifndef HAVE_nbif_ets_match_1
#define HAVE_nbif_ets_match_1
	.global	nbif_ets_match_1
nbif_ets_match_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_match_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ets_match_1, .-nbif_ets_match_1
	.type	nbif_ets_match_1, %function
#endif

#ifndef HAVE_nbif_ets_match_2
#define HAVE_nbif_ets_match_2
	.global	nbif_ets_match_2
nbif_ets_match_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_match_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_match_2, .-nbif_ets_match_2
	.type	nbif_ets_match_2, %function
#endif

#ifndef HAVE_nbif_ets_match_3
#define HAVE_nbif_ets_match_3
	.global	nbif_ets_match_3
nbif_ets_match_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_match_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_match_3, .-nbif_ets_match_3
	.type	nbif_ets_match_3, %function
#endif

#ifndef HAVE_nbif_ets_match_object_1
#define HAVE_nbif_ets_match_object_1
	.global	nbif_ets_match_object_1
nbif_ets_match_object_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_match_object_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ets_match_object_1, .-nbif_ets_match_object_1
	.type	nbif_ets_match_object_1, %function
#endif

#ifndef HAVE_nbif_ets_match_object_2
#define HAVE_nbif_ets_match_object_2
	.global	nbif_ets_match_object_2
nbif_ets_match_object_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_match_object_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_match_object_2, .-nbif_ets_match_object_2
	.type	nbif_ets_match_object_2, %function
#endif

#ifndef HAVE_nbif_ets_match_object_3
#define HAVE_nbif_ets_match_object_3
	.global	nbif_ets_match_object_3
nbif_ets_match_object_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_match_object_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_match_object_3, .-nbif_ets_match_object_3
	.type	nbif_ets_match_object_3, %function
#endif

#ifndef HAVE_nbif_ets_member_2
#define HAVE_nbif_ets_member_2
	.global	nbif_ets_member_2
nbif_ets_member_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_member_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_member_2, .-nbif_ets_member_2
	.type	nbif_ets_member_2, %function
#endif

#ifndef HAVE_nbif_ets_next_2
#define HAVE_nbif_ets_next_2
	.global	nbif_ets_next_2
nbif_ets_next_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_next_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_next_2, .-nbif_ets_next_2
	.type	nbif_ets_next_2, %function
#endif

#ifndef HAVE_nbif_ets_prev_2
#define HAVE_nbif_ets_prev_2
	.global	nbif_ets_prev_2
nbif_ets_prev_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_prev_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_prev_2, .-nbif_ets_prev_2
	.type	nbif_ets_prev_2, %function
#endif

#ifndef HAVE_nbif_ets_insert_2
#define HAVE_nbif_ets_insert_2
	.global	nbif_ets_insert_2
nbif_ets_insert_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_insert_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_insert_2, .-nbif_ets_insert_2
	.type	nbif_ets_insert_2, %function
#endif

#ifndef HAVE_nbif_ets_insert_new_2
#define HAVE_nbif_ets_insert_new_2
	.global	nbif_ets_insert_new_2
nbif_ets_insert_new_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_insert_new_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_insert_new_2, .-nbif_ets_insert_new_2
	.type	nbif_ets_insert_new_2, %function
#endif

#ifndef HAVE_nbif_ets_rename_2
#define HAVE_nbif_ets_rename_2
	.global	nbif_ets_rename_2
nbif_ets_rename_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_rename_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_rename_2, .-nbif_ets_rename_2
	.type	nbif_ets_rename_2, %function
#endif

#ifndef HAVE_nbif_ets_safe_fixtable_2
#define HAVE_nbif_ets_safe_fixtable_2
	.global	nbif_ets_safe_fixtable_2
nbif_ets_safe_fixtable_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_safe_fixtable_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_safe_fixtable_2, .-nbif_ets_safe_fixtable_2
	.type	nbif_ets_safe_fixtable_2, %function
#endif

#ifndef HAVE_nbif_ets_slot_2
#define HAVE_nbif_ets_slot_2
	.global	nbif_ets_slot_2
nbif_ets_slot_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_slot_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_slot_2, .-nbif_ets_slot_2
	.type	nbif_ets_slot_2, %function
#endif

#ifndef HAVE_nbif_ets_update_counter_3
#define HAVE_nbif_ets_update_counter_3
	.global	nbif_ets_update_counter_3
nbif_ets_update_counter_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_update_counter_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_update_counter_3, .-nbif_ets_update_counter_3
	.type	nbif_ets_update_counter_3, %function
#endif

#ifndef HAVE_nbif_ets_select_1
#define HAVE_nbif_ets_select_1
	.global	nbif_ets_select_1
nbif_ets_select_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_select_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ets_select_1, .-nbif_ets_select_1
	.type	nbif_ets_select_1, %function
#endif

#ifndef HAVE_nbif_ets_select_2
#define HAVE_nbif_ets_select_2
	.global	nbif_ets_select_2
nbif_ets_select_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_select_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_select_2, .-nbif_ets_select_2
	.type	nbif_ets_select_2, %function
#endif

#ifndef HAVE_nbif_ets_select_3
#define HAVE_nbif_ets_select_3
	.global	nbif_ets_select_3
nbif_ets_select_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_select_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_select_3, .-nbif_ets_select_3
	.type	nbif_ets_select_3, %function
#endif

#ifndef HAVE_nbif_ets_select_count_2
#define HAVE_nbif_ets_select_count_2
	.global	nbif_ets_select_count_2
nbif_ets_select_count_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_select_count_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_select_count_2, .-nbif_ets_select_count_2
	.type	nbif_ets_select_count_2, %function
#endif

#ifndef HAVE_nbif_ets_select_reverse_1
#define HAVE_nbif_ets_select_reverse_1
	.global	nbif_ets_select_reverse_1
nbif_ets_select_reverse_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_select_reverse_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ets_select_reverse_1, .-nbif_ets_select_reverse_1
	.type	nbif_ets_select_reverse_1, %function
#endif

#ifndef HAVE_nbif_ets_select_reverse_2
#define HAVE_nbif_ets_select_reverse_2
	.global	nbif_ets_select_reverse_2
nbif_ets_select_reverse_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_select_reverse_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_select_reverse_2, .-nbif_ets_select_reverse_2
	.type	nbif_ets_select_reverse_2, %function
#endif

#ifndef HAVE_nbif_ets_select_reverse_3
#define HAVE_nbif_ets_select_reverse_3
	.global	nbif_ets_select_reverse_3
nbif_ets_select_reverse_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_select_reverse_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_select_reverse_3, .-nbif_ets_select_reverse_3
	.type	nbif_ets_select_reverse_3, %function
#endif

#ifndef HAVE_nbif_ets_select_delete_2
#define HAVE_nbif_ets_select_delete_2
	.global	nbif_ets_select_delete_2
nbif_ets_select_delete_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_select_delete_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_select_delete_2, .-nbif_ets_select_delete_2
	.type	nbif_ets_select_delete_2, %function
#endif

#ifndef HAVE_nbif_ets_match_spec_compile_1
#define HAVE_nbif_ets_match_spec_compile_1
	.global	nbif_ets_match_spec_compile_1
nbif_ets_match_spec_compile_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_match_spec_compile_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_ets_match_spec_compile_1, .-nbif_ets_match_spec_compile_1
	.type	nbif_ets_match_spec_compile_1, %function
#endif

#ifndef HAVE_nbif_ets_match_spec_run_r_3
#define HAVE_nbif_ets_match_spec_run_r_3
	.global	nbif_ets_match_spec_run_r_3
nbif_ets_match_spec_run_r_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_match_spec_run_r_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_match_spec_run_r_3, .-nbif_ets_match_spec_run_r_3
	.type	nbif_ets_match_spec_run_r_3, %function
#endif

#ifndef HAVE_nbif_os_putenv_2
#define HAVE_nbif_os_putenv_2
	.global	nbif_os_putenv_2
nbif_os_putenv_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(os_putenv_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_os_putenv_2, .-nbif_os_putenv_2
	.type	nbif_os_putenv_2, %function
#endif

#ifndef HAVE_nbif_os_getenv_0
#define HAVE_nbif_os_getenv_0
	.global	nbif_os_getenv_0
nbif_os_getenv_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(os_getenv_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_os_getenv_0, .-nbif_os_getenv_0
	.type	nbif_os_getenv_0, %function
#endif

#ifndef HAVE_nbif_os_getenv_1
#define HAVE_nbif_os_getenv_1
	.global	nbif_os_getenv_1
nbif_os_getenv_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(os_getenv_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_os_getenv_1, .-nbif_os_getenv_1
	.type	nbif_os_getenv_1, %function
#endif

#ifndef HAVE_nbif_os_getpid_0
#define HAVE_nbif_os_getpid_0
	.global	nbif_os_getpid_0
nbif_os_getpid_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(os_getpid_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_os_getpid_0, .-nbif_os_getpid_0
	.type	nbif_os_getpid_0, %function
#endif

#ifndef HAVE_nbif_os_timestamp_0
#define HAVE_nbif_os_timestamp_0
	.global	nbif_os_timestamp_0
nbif_os_timestamp_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(os_timestamp_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_os_timestamp_0, .-nbif_os_timestamp_0
	.type	nbif_os_timestamp_0, %function
#endif

#ifndef HAVE_nbif_erl_ddll_try_load_3
#define HAVE_nbif_erl_ddll_try_load_3
	.global	nbif_erl_ddll_try_load_3
nbif_erl_ddll_try_load_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(erl_ddll_try_load_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erl_ddll_try_load_3, .-nbif_erl_ddll_try_load_3
	.type	nbif_erl_ddll_try_load_3, %function
#endif

#ifndef HAVE_nbif_erl_ddll_try_unload_2
#define HAVE_nbif_erl_ddll_try_unload_2
	.global	nbif_erl_ddll_try_unload_2
nbif_erl_ddll_try_unload_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(erl_ddll_try_unload_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erl_ddll_try_unload_2, .-nbif_erl_ddll_try_unload_2
	.type	nbif_erl_ddll_try_unload_2, %function
#endif

#ifndef HAVE_nbif_erl_ddll_loaded_drivers_0
#define HAVE_nbif_erl_ddll_loaded_drivers_0
	.global	nbif_erl_ddll_loaded_drivers_0
nbif_erl_ddll_loaded_drivers_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(erl_ddll_loaded_drivers_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erl_ddll_loaded_drivers_0, .-nbif_erl_ddll_loaded_drivers_0
	.type	nbif_erl_ddll_loaded_drivers_0, %function
#endif

#ifndef HAVE_nbif_erl_ddll_info_2
#define HAVE_nbif_erl_ddll_info_2
	.global	nbif_erl_ddll_info_2
nbif_erl_ddll_info_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(erl_ddll_info_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erl_ddll_info_2, .-nbif_erl_ddll_info_2
	.type	nbif_erl_ddll_info_2, %function
#endif

#ifndef HAVE_nbif_erl_ddll_format_error_int_1
#define HAVE_nbif_erl_ddll_format_error_int_1
	.global	nbif_erl_ddll_format_error_int_1
nbif_erl_ddll_format_error_int_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erl_ddll_format_error_int_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erl_ddll_format_error_int_1, .-nbif_erl_ddll_format_error_int_1
	.type	nbif_erl_ddll_format_error_int_1, %function
#endif

#ifndef HAVE_nbif_erl_ddll_monitor_2
#define HAVE_nbif_erl_ddll_monitor_2
	.global	nbif_erl_ddll_monitor_2
nbif_erl_ddll_monitor_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(erl_ddll_monitor_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erl_ddll_monitor_2, .-nbif_erl_ddll_monitor_2
	.type	nbif_erl_ddll_monitor_2, %function
#endif

#ifndef HAVE_nbif_erl_ddll_demonitor_1
#define HAVE_nbif_erl_ddll_demonitor_1
	.global	nbif_erl_ddll_demonitor_1
nbif_erl_ddll_demonitor_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erl_ddll_demonitor_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erl_ddll_demonitor_1, .-nbif_erl_ddll_demonitor_1
	.type	nbif_erl_ddll_demonitor_1, %function
#endif

#ifndef HAVE_nbif_re_compile_1
#define HAVE_nbif_re_compile_1
	.global	nbif_re_compile_1
nbif_re_compile_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(re_compile_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_re_compile_1, .-nbif_re_compile_1
	.type	nbif_re_compile_1, %function
#endif

#ifndef HAVE_nbif_re_compile_2
#define HAVE_nbif_re_compile_2
	.global	nbif_re_compile_2
nbif_re_compile_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(re_compile_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_re_compile_2, .-nbif_re_compile_2
	.type	nbif_re_compile_2, %function
#endif

#ifndef HAVE_nbif_re_run_2
#define HAVE_nbif_re_run_2
	.global	nbif_re_run_2
nbif_re_run_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(re_run_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_re_run_2, .-nbif_re_run_2
	.type	nbif_re_run_2, %function
#endif

#ifndef HAVE_nbif_re_run_3
#define HAVE_nbif_re_run_3
	.global	nbif_re_run_3
nbif_re_run_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(re_run_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_re_run_3, .-nbif_re_run_3
	.type	nbif_re_run_3, %function
#endif

#ifndef HAVE_nbif_lists_member_2
#define HAVE_nbif_lists_member_2
	.global	nbif_lists_member_2
nbif_lists_member_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(lists_member_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_lists_member_2, .-nbif_lists_member_2
	.type	nbif_lists_member_2, %function
#endif

#ifndef HAVE_nbif_lists_reverse_2
#define HAVE_nbif_lists_reverse_2
	.global	nbif_lists_reverse_2
nbif_lists_reverse_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(lists_reverse_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_lists_reverse_2, .-nbif_lists_reverse_2
	.type	nbif_lists_reverse_2, %function
#endif

#ifndef HAVE_nbif_lists_keymember_3
#define HAVE_nbif_lists_keymember_3
	.global	nbif_lists_keymember_3
nbif_lists_keymember_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(lists_keymember_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_lists_keymember_3, .-nbif_lists_keymember_3
	.type	nbif_lists_keymember_3, %function
#endif

#ifndef HAVE_nbif_lists_keysearch_3
#define HAVE_nbif_lists_keysearch_3
	.global	nbif_lists_keysearch_3
nbif_lists_keysearch_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(lists_keysearch_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_lists_keysearch_3, .-nbif_lists_keysearch_3
	.type	nbif_lists_keysearch_3, %function
#endif

#ifndef HAVE_nbif_lists_keyfind_3
#define HAVE_nbif_lists_keyfind_3
	.global	nbif_lists_keyfind_3
nbif_lists_keyfind_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(lists_keyfind_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_lists_keyfind_3, .-nbif_lists_keyfind_3
	.type	nbif_lists_keyfind_3, %function
#endif

#ifndef HAVE_nbif_erts_debug_disassemble_1
#define HAVE_nbif_erts_debug_disassemble_1
	.global	nbif_erts_debug_disassemble_1
nbif_erts_debug_disassemble_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_debug_disassemble_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erts_debug_disassemble_1, .-nbif_erts_debug_disassemble_1
	.type	nbif_erts_debug_disassemble_1, %function
#endif

#ifndef HAVE_nbif_erts_debug_breakpoint_2
#define HAVE_nbif_erts_debug_breakpoint_2
	.global	nbif_erts_debug_breakpoint_2
nbif_erts_debug_breakpoint_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_debug_breakpoint_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_debug_breakpoint_2, .-nbif_erts_debug_breakpoint_2
	.type	nbif_erts_debug_breakpoint_2, %function
#endif

#ifndef HAVE_nbif_erts_debug_same_2
#define HAVE_nbif_erts_debug_same_2
	.global	nbif_erts_debug_same_2
nbif_erts_debug_same_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_debug_same_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_debug_same_2, .-nbif_erts_debug_same_2
	.type	nbif_erts_debug_same_2, %function
#endif

#ifndef HAVE_nbif_erts_debug_flat_size_1
#define HAVE_nbif_erts_debug_flat_size_1
	.global	nbif_erts_debug_flat_size_1
nbif_erts_debug_flat_size_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_debug_flat_size_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erts_debug_flat_size_1, .-nbif_erts_debug_flat_size_1
	.type	nbif_erts_debug_flat_size_1, %function
#endif

#ifndef HAVE_nbif_erts_debug_get_internal_state_1
#define HAVE_nbif_erts_debug_get_internal_state_1
	.global	nbif_erts_debug_get_internal_state_1
nbif_erts_debug_get_internal_state_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_debug_get_internal_state_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erts_debug_get_internal_state_1, .-nbif_erts_debug_get_internal_state_1
	.type	nbif_erts_debug_get_internal_state_1, %function
#endif

#ifndef HAVE_nbif_erts_debug_set_internal_state_2
#define HAVE_nbif_erts_debug_set_internal_state_2
	.global	nbif_erts_debug_set_internal_state_2
nbif_erts_debug_set_internal_state_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_debug_set_internal_state_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_debug_set_internal_state_2, .-nbif_erts_debug_set_internal_state_2
	.type	nbif_erts_debug_set_internal_state_2, %function
#endif

#ifndef HAVE_nbif_erts_debug_display_1
#define HAVE_nbif_erts_debug_display_1
	.global	nbif_erts_debug_display_1
nbif_erts_debug_display_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_debug_display_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erts_debug_display_1, .-nbif_erts_debug_display_1
	.type	nbif_erts_debug_display_1, %function
#endif

#ifndef HAVE_nbif_erts_debug_dist_ext_to_term_2
#define HAVE_nbif_erts_debug_dist_ext_to_term_2
	.global	nbif_erts_debug_dist_ext_to_term_2
nbif_erts_debug_dist_ext_to_term_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_debug_dist_ext_to_term_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_debug_dist_ext_to_term_2, .-nbif_erts_debug_dist_ext_to_term_2
	.type	nbif_erts_debug_dist_ext_to_term_2, %function
#endif

#ifndef HAVE_nbif_erts_debug_instructions_0
#define HAVE_nbif_erts_debug_instructions_0
	.global	nbif_erts_debug_instructions_0
nbif_erts_debug_instructions_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(erts_debug_instructions_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_debug_instructions_0, .-nbif_erts_debug_instructions_0
	.type	nbif_erts_debug_instructions_0, %function
#endif

#ifndef HAVE_nbif_erts_debug_dump_monitors_1
#define HAVE_nbif_erts_debug_dump_monitors_1
	.global	nbif_erts_debug_dump_monitors_1
nbif_erts_debug_dump_monitors_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_debug_dump_monitors_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erts_debug_dump_monitors_1, .-nbif_erts_debug_dump_monitors_1
	.type	nbif_erts_debug_dump_monitors_1, %function
#endif

#ifndef HAVE_nbif_erts_debug_dump_links_1
#define HAVE_nbif_erts_debug_dump_links_1
	.global	nbif_erts_debug_dump_links_1
nbif_erts_debug_dump_links_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_debug_dump_links_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erts_debug_dump_links_1, .-nbif_erts_debug_dump_links_1
	.type	nbif_erts_debug_dump_links_1, %function
#endif

#ifndef HAVE_nbif_erts_debug_lock_counters_1
#define HAVE_nbif_erts_debug_lock_counters_1
	.global	nbif_erts_debug_lock_counters_1
nbif_erts_debug_lock_counters_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_debug_lock_counters_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_erts_debug_lock_counters_1, .-nbif_erts_debug_lock_counters_1
	.type	nbif_erts_debug_lock_counters_1, %function
#endif

#ifndef HAVE_nbif_code_get_chunk_2
#define HAVE_nbif_code_get_chunk_2
	.global	nbif_code_get_chunk_2
nbif_code_get_chunk_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(code_get_chunk_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_code_get_chunk_2, .-nbif_code_get_chunk_2
	.type	nbif_code_get_chunk_2, %function
#endif

#ifndef HAVE_nbif_code_module_md5_1
#define HAVE_nbif_code_module_md5_1
	.global	nbif_code_module_md5_1
nbif_code_module_md5_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(code_module_md5_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_code_module_md5_1, .-nbif_code_module_md5_1
	.type	nbif_code_module_md5_1, %function
#endif

#ifndef HAVE_nbif_code_make_stub_module_3
#define HAVE_nbif_code_make_stub_module_3
	.global	nbif_code_make_stub_module_3
nbif_code_make_stub_module_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(code_make_stub_module_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_code_make_stub_module_3, .-nbif_code_make_stub_module_3
	.type	nbif_code_make_stub_module_3, %function
#endif

#ifndef HAVE_nbif_code_is_module_native_1
#define HAVE_nbif_code_is_module_native_1
	.global	nbif_code_is_module_native_1
nbif_code_is_module_native_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(code_is_module_native_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_code_is_module_native_1, .-nbif_code_is_module_native_1
	.type	nbif_code_is_module_native_1, %function
#endif

#ifndef HAVE_nbif_hibernate_3
#define HAVE_nbif_hibernate_3
	.global	nbif_hibernate_3
nbif_hibernate_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hibernate_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hibernate_3, .-nbif_hibernate_3
	.type	nbif_hibernate_3, %function
#endif

#ifndef HAVE_nbif_error_logger_warning_map_0
#define HAVE_nbif_error_logger_warning_map_0
	.global	nbif_error_logger_warning_map_0
nbif_error_logger_warning_map_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(error_logger_warning_map_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_error_logger_warning_map_0, .-nbif_error_logger_warning_map_0
	.type	nbif_error_logger_warning_map_0, %function
#endif

#ifndef HAVE_nbif_get_module_info_1
#define HAVE_nbif_get_module_info_1
	.global	nbif_get_module_info_1
nbif_get_module_info_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(get_module_info_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_get_module_info_1, .-nbif_get_module_info_1
	.type	nbif_get_module_info_1, %function
#endif

#ifndef HAVE_nbif_get_module_info_2
#define HAVE_nbif_get_module_info_2
	.global	nbif_get_module_info_2
nbif_get_module_info_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(get_module_info_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_get_module_info_2, .-nbif_get_module_info_2
	.type	nbif_get_module_info_2, %function
#endif

#ifndef HAVE_nbif_is_boolean_1
#define HAVE_nbif_is_boolean_1
	.global	nbif_is_boolean_1
nbif_is_boolean_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_boolean_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_boolean_1, .-nbif_is_boolean_1
	.type	nbif_is_boolean_1, %function
#endif

#ifndef HAVE_nbif_string_to_integer_1
#define HAVE_nbif_string_to_integer_1
	.global	nbif_string_to_integer_1
nbif_string_to_integer_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(string_to_integer_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_string_to_integer_1, .-nbif_string_to_integer_1
	.type	nbif_string_to_integer_1, %function
#endif

#ifndef HAVE_nbif_string_to_float_1
#define HAVE_nbif_string_to_float_1
	.global	nbif_string_to_float_1
nbif_string_to_float_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(string_to_float_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_string_to_float_1, .-nbif_string_to_float_1
	.type	nbif_string_to_float_1, %function
#endif

#ifndef HAVE_nbif_make_fun_3
#define HAVE_nbif_make_fun_3
	.global	nbif_make_fun_3
nbif_make_fun_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(make_fun_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_make_fun_3, .-nbif_make_fun_3
	.type	nbif_make_fun_3, %function
#endif

#ifndef HAVE_nbif_iolist_size_1
#define HAVE_nbif_iolist_size_1
	.global	nbif_iolist_size_1
nbif_iolist_size_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(iolist_size_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_iolist_size_1, .-nbif_iolist_size_1
	.type	nbif_iolist_size_1, %function
#endif

#ifndef HAVE_nbif_iolist_to_binary_1
#define HAVE_nbif_iolist_to_binary_1
	.global	nbif_iolist_to_binary_1
nbif_iolist_to_binary_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_wrapper_iolist_to_binary_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_iolist_to_binary_1, .-nbif_iolist_to_binary_1
	.type	nbif_iolist_to_binary_1, %function
#endif

#ifndef HAVE_nbif_list_to_existing_atom_1
#define HAVE_nbif_list_to_existing_atom_1
	.global	nbif_list_to_existing_atom_1
nbif_list_to_existing_atom_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(list_to_existing_atom_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_list_to_existing_atom_1, .-nbif_list_to_existing_atom_1
	.type	nbif_list_to_existing_atom_1, %function
#endif

#ifndef HAVE_nbif_is_bitstring_1
#define HAVE_nbif_is_bitstring_1
	.global	nbif_is_bitstring_1
nbif_is_bitstring_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_bitstring_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_bitstring_1, .-nbif_is_bitstring_1
	.type	nbif_is_bitstring_1, %function
#endif

#ifndef HAVE_nbif_tuple_size_1
#define HAVE_nbif_tuple_size_1
	.global	nbif_tuple_size_1
nbif_tuple_size_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(tuple_size_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_tuple_size_1, .-nbif_tuple_size_1
	.type	nbif_tuple_size_1, %function
#endif

#ifndef HAVE_nbif_byte_size_1
#define HAVE_nbif_byte_size_1
	.global	nbif_byte_size_1
nbif_byte_size_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(byte_size_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_byte_size_1, .-nbif_byte_size_1
	.type	nbif_byte_size_1, %function
#endif

#ifndef HAVE_nbif_bit_size_1
#define HAVE_nbif_bit_size_1
	.global	nbif_bit_size_1
nbif_bit_size_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(bit_size_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_bit_size_1, .-nbif_bit_size_1
	.type	nbif_bit_size_1, %function
#endif

#ifndef HAVE_nbif_list_to_bitstring_1
#define HAVE_nbif_list_to_bitstring_1
	.global	nbif_list_to_bitstring_1
nbif_list_to_bitstring_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_wrapper_list_to_bitstring_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_list_to_bitstring_1, .-nbif_list_to_bitstring_1
	.type	nbif_list_to_bitstring_1, %function
#endif

#ifndef HAVE_nbif_bitstring_to_list_1
#define HAVE_nbif_bitstring_to_list_1
	.global	nbif_bitstring_to_list_1
nbif_bitstring_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_wrapper_bitstring_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_bitstring_to_list_1, .-nbif_bitstring_to_list_1
	.type	nbif_bitstring_to_list_1, %function
#endif

#ifndef HAVE_nbif_ets_update_element_3
#define HAVE_nbif_ets_update_element_3
	.global	nbif_ets_update_element_3
nbif_ets_update_element_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_update_element_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_update_element_3, .-nbif_ets_update_element_3
	.type	nbif_ets_update_element_3, %function
#endif

#ifndef HAVE_nbif_decode_packet_3
#define HAVE_nbif_decode_packet_3
	.global	nbif_decode_packet_3
nbif_decode_packet_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(decode_packet_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_decode_packet_3, .-nbif_decode_packet_3
	.type	nbif_decode_packet_3, %function
#endif

#ifndef HAVE_nbif_unicode_characters_to_binary_2
#define HAVE_nbif_unicode_characters_to_binary_2
	.global	nbif_unicode_characters_to_binary_2
nbif_unicode_characters_to_binary_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(unicode_characters_to_binary_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_unicode_characters_to_binary_2, .-nbif_unicode_characters_to_binary_2
	.type	nbif_unicode_characters_to_binary_2, %function
#endif

#ifndef HAVE_nbif_unicode_characters_to_list_2
#define HAVE_nbif_unicode_characters_to_list_2
	.global	nbif_unicode_characters_to_list_2
nbif_unicode_characters_to_list_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(unicode_characters_to_list_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_unicode_characters_to_list_2, .-nbif_unicode_characters_to_list_2
	.type	nbif_unicode_characters_to_list_2, %function
#endif

#ifndef HAVE_nbif_unicode_bin_is_7bit_1
#define HAVE_nbif_unicode_bin_is_7bit_1
	.global	nbif_unicode_bin_is_7bit_1
nbif_unicode_bin_is_7bit_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(unicode_bin_is_7bit_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_unicode_bin_is_7bit_1, .-nbif_unicode_bin_is_7bit_1
	.type	nbif_unicode_bin_is_7bit_1, %function
#endif

#ifndef HAVE_nbif_atom_to_binary_2
#define HAVE_nbif_atom_to_binary_2
	.global	nbif_atom_to_binary_2
nbif_atom_to_binary_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(atom_to_binary_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_atom_to_binary_2, .-nbif_atom_to_binary_2
	.type	nbif_atom_to_binary_2, %function
#endif

#ifndef HAVE_nbif_binary_to_atom_2
#define HAVE_nbif_binary_to_atom_2
	.global	nbif_binary_to_atom_2
nbif_binary_to_atom_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_to_atom_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_to_atom_2, .-nbif_binary_to_atom_2
	.type	nbif_binary_to_atom_2, %function
#endif

#ifndef HAVE_nbif_binary_to_existing_atom_2
#define HAVE_nbif_binary_to_existing_atom_2
	.global	nbif_binary_to_existing_atom_2
nbif_binary_to_existing_atom_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_to_existing_atom_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_to_existing_atom_2, .-nbif_binary_to_existing_atom_2
	.type	nbif_binary_to_existing_atom_2, %function
#endif

#ifndef HAVE_nbif_net_kernel_dflag_unicode_io_1
#define HAVE_nbif_net_kernel_dflag_unicode_io_1
	.global	nbif_net_kernel_dflag_unicode_io_1
nbif_net_kernel_dflag_unicode_io_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(net_kernel_dflag_unicode_io_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_net_kernel_dflag_unicode_io_1, .-nbif_net_kernel_dflag_unicode_io_1
	.type	nbif_net_kernel_dflag_unicode_io_1, %function
#endif

#ifndef HAVE_nbif_ets_give_away_3
#define HAVE_nbif_ets_give_away_3
	.global	nbif_ets_give_away_3
nbif_ets_give_away_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_give_away_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_give_away_3, .-nbif_ets_give_away_3
	.type	nbif_ets_give_away_3, %function
#endif

#ifndef HAVE_nbif_ets_setopts_2
#define HAVE_nbif_ets_setopts_2
	.global	nbif_ets_setopts_2
nbif_ets_setopts_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(ets_setopts_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_ets_setopts_2, .-nbif_ets_setopts_2
	.type	nbif_ets_setopts_2, %function
#endif

#ifndef HAVE_nbif_load_nif_2
#define HAVE_nbif_load_nif_2
	.global	nbif_load_nif_2
nbif_load_nif_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(load_nif_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_load_nif_2, .-nbif_load_nif_2
	.type	nbif_load_nif_2, %function
#endif

#ifndef HAVE_nbif_call_on_load_function_1
#define HAVE_nbif_call_on_load_function_1
	.global	nbif_call_on_load_function_1
nbif_call_on_load_function_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(call_on_load_function_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_call_on_load_function_1, .-nbif_call_on_load_function_1
	.type	nbif_call_on_load_function_1, %function
#endif

#ifndef HAVE_nbif_finish_after_on_load_2
#define HAVE_nbif_finish_after_on_load_2
	.global	nbif_finish_after_on_load_2
nbif_finish_after_on_load_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(finish_after_on_load_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_finish_after_on_load_2, .-nbif_finish_after_on_load_2
	.type	nbif_finish_after_on_load_2, %function
#endif

#ifndef HAVE_nbif_binary_to_term_2
#define HAVE_nbif_binary_to_term_2
	.global	nbif_binary_to_term_2
nbif_binary_to_term_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_wrapper_binary_to_term_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_to_term_2, .-nbif_binary_to_term_2
	.type	nbif_binary_to_term_2, %function
#endif

#ifndef HAVE_nbif_binary_part_2
#define HAVE_nbif_binary_part_2
	.global	nbif_binary_part_2
nbif_binary_part_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_part_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_part_2, .-nbif_binary_part_2
	.type	nbif_binary_part_2, %function
#endif

#ifndef HAVE_nbif_binary_part_3
#define HAVE_nbif_binary_part_3
	.global	nbif_binary_part_3
nbif_binary_part_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_part_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_part_3, .-nbif_binary_part_3
	.type	nbif_binary_part_3, %function
#endif

#ifndef HAVE_nbif_binary_compile_pattern_1
#define HAVE_nbif_binary_compile_pattern_1
	.global	nbif_binary_compile_pattern_1
nbif_binary_compile_pattern_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_compile_pattern_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_compile_pattern_1, .-nbif_binary_compile_pattern_1
	.type	nbif_binary_compile_pattern_1, %function
#endif

#ifndef HAVE_nbif_binary_match_2
#define HAVE_nbif_binary_match_2
	.global	nbif_binary_match_2
nbif_binary_match_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_match_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_match_2, .-nbif_binary_match_2
	.type	nbif_binary_match_2, %function
#endif

#ifndef HAVE_nbif_binary_match_3
#define HAVE_nbif_binary_match_3
	.global	nbif_binary_match_3
nbif_binary_match_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_match_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_match_3, .-nbif_binary_match_3
	.type	nbif_binary_match_3, %function
#endif

#ifndef HAVE_nbif_binary_matches_2
#define HAVE_nbif_binary_matches_2
	.global	nbif_binary_matches_2
nbif_binary_matches_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_matches_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_matches_2, .-nbif_binary_matches_2
	.type	nbif_binary_matches_2, %function
#endif

#ifndef HAVE_nbif_binary_matches_3
#define HAVE_nbif_binary_matches_3
	.global	nbif_binary_matches_3
nbif_binary_matches_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_matches_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_matches_3, .-nbif_binary_matches_3
	.type	nbif_binary_matches_3, %function
#endif

#ifndef HAVE_nbif_binary_longest_common_prefix_1
#define HAVE_nbif_binary_longest_common_prefix_1
	.global	nbif_binary_longest_common_prefix_1
nbif_binary_longest_common_prefix_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_longest_common_prefix_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_longest_common_prefix_1, .-nbif_binary_longest_common_prefix_1
	.type	nbif_binary_longest_common_prefix_1, %function
#endif

#ifndef HAVE_nbif_binary_longest_common_suffix_1
#define HAVE_nbif_binary_longest_common_suffix_1
	.global	nbif_binary_longest_common_suffix_1
nbif_binary_longest_common_suffix_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_longest_common_suffix_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_longest_common_suffix_1, .-nbif_binary_longest_common_suffix_1
	.type	nbif_binary_longest_common_suffix_1, %function
#endif

#ifndef HAVE_nbif_binary_first_1
#define HAVE_nbif_binary_first_1
	.global	nbif_binary_first_1
nbif_binary_first_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_first_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_first_1, .-nbif_binary_first_1
	.type	nbif_binary_first_1, %function
#endif

#ifndef HAVE_nbif_binary_last_1
#define HAVE_nbif_binary_last_1
	.global	nbif_binary_last_1
nbif_binary_last_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_last_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_last_1, .-nbif_binary_last_1
	.type	nbif_binary_last_1, %function
#endif

#ifndef HAVE_nbif_binary_at_2
#define HAVE_nbif_binary_at_2
	.global	nbif_binary_at_2
nbif_binary_at_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_at_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_at_2, .-nbif_binary_at_2
	.type	nbif_binary_at_2, %function
#endif

#ifndef HAVE_nbif_binary_binary_part_2
#define HAVE_nbif_binary_binary_part_2
	.global	nbif_binary_binary_part_2
nbif_binary_binary_part_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_binary_part_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_binary_part_2, .-nbif_binary_binary_part_2
	.type	nbif_binary_binary_part_2, %function
#endif

#ifndef HAVE_nbif_binary_binary_part_3
#define HAVE_nbif_binary_binary_part_3
	.global	nbif_binary_binary_part_3
nbif_binary_binary_part_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_binary_part_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_binary_part_3, .-nbif_binary_binary_part_3
	.type	nbif_binary_binary_part_3, %function
#endif

#ifndef HAVE_nbif_binary_bin_to_list_1
#define HAVE_nbif_binary_bin_to_list_1
	.global	nbif_binary_bin_to_list_1
nbif_binary_bin_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_bin_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_bin_to_list_1, .-nbif_binary_bin_to_list_1
	.type	nbif_binary_bin_to_list_1, %function
#endif

#ifndef HAVE_nbif_binary_bin_to_list_2
#define HAVE_nbif_binary_bin_to_list_2
	.global	nbif_binary_bin_to_list_2
nbif_binary_bin_to_list_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_bin_to_list_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_bin_to_list_2, .-nbif_binary_bin_to_list_2
	.type	nbif_binary_bin_to_list_2, %function
#endif

#ifndef HAVE_nbif_binary_bin_to_list_3
#define HAVE_nbif_binary_bin_to_list_3
	.global	nbif_binary_bin_to_list_3
nbif_binary_bin_to_list_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_bin_to_list_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_bin_to_list_3, .-nbif_binary_bin_to_list_3
	.type	nbif_binary_bin_to_list_3, %function
#endif

#ifndef HAVE_nbif_binary_list_to_bin_1
#define HAVE_nbif_binary_list_to_bin_1
	.global	nbif_binary_list_to_bin_1
nbif_binary_list_to_bin_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_wrapper_binary_list_to_bin_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_list_to_bin_1, .-nbif_binary_list_to_bin_1
	.type	nbif_binary_list_to_bin_1, %function
#endif

#ifndef HAVE_nbif_binary_copy_1
#define HAVE_nbif_binary_copy_1
	.global	nbif_binary_copy_1
nbif_binary_copy_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_copy_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_copy_1, .-nbif_binary_copy_1
	.type	nbif_binary_copy_1, %function
#endif

#ifndef HAVE_nbif_binary_copy_2
#define HAVE_nbif_binary_copy_2
	.global	nbif_binary_copy_2
nbif_binary_copy_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_copy_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_copy_2, .-nbif_binary_copy_2
	.type	nbif_binary_copy_2, %function
#endif

#ifndef HAVE_nbif_binary_referenced_byte_size_1
#define HAVE_nbif_binary_referenced_byte_size_1
	.global	nbif_binary_referenced_byte_size_1
nbif_binary_referenced_byte_size_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_referenced_byte_size_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_referenced_byte_size_1, .-nbif_binary_referenced_byte_size_1
	.type	nbif_binary_referenced_byte_size_1, %function
#endif

#ifndef HAVE_nbif_binary_encode_unsigned_1
#define HAVE_nbif_binary_encode_unsigned_1
	.global	nbif_binary_encode_unsigned_1
nbif_binary_encode_unsigned_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_encode_unsigned_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_encode_unsigned_1, .-nbif_binary_encode_unsigned_1
	.type	nbif_binary_encode_unsigned_1, %function
#endif

#ifndef HAVE_nbif_binary_encode_unsigned_2
#define HAVE_nbif_binary_encode_unsigned_2
	.global	nbif_binary_encode_unsigned_2
nbif_binary_encode_unsigned_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_encode_unsigned_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_encode_unsigned_2, .-nbif_binary_encode_unsigned_2
	.type	nbif_binary_encode_unsigned_2, %function
#endif

#ifndef HAVE_nbif_binary_decode_unsigned_1
#define HAVE_nbif_binary_decode_unsigned_1
	.global	nbif_binary_decode_unsigned_1
nbif_binary_decode_unsigned_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_decode_unsigned_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_decode_unsigned_1, .-nbif_binary_decode_unsigned_1
	.type	nbif_binary_decode_unsigned_1, %function
#endif

#ifndef HAVE_nbif_binary_decode_unsigned_2
#define HAVE_nbif_binary_decode_unsigned_2
	.global	nbif_binary_decode_unsigned_2
nbif_binary_decode_unsigned_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_decode_unsigned_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_decode_unsigned_2, .-nbif_binary_decode_unsigned_2
	.type	nbif_binary_decode_unsigned_2, %function
#endif

#ifndef HAVE_nbif_nif_error_1
#define HAVE_nbif_nif_error_1
	.global	nbif_nif_error_1
nbif_nif_error_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(nif_error_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_nif_error_1, .-nbif_nif_error_1
	.type	nbif_nif_error_1, %function
#endif

#ifndef HAVE_nbif_nif_error_2
#define HAVE_nbif_nif_error_2
	.global	nbif_nif_error_2
nbif_nif_error_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(nif_error_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_nif_error_2, .-nbif_nif_error_2
	.type	nbif_nif_error_2, %function
#endif

#ifndef HAVE_nbif_prim_file_internal_name2native_1
#define HAVE_nbif_prim_file_internal_name2native_1
	.global	nbif_prim_file_internal_name2native_1
nbif_prim_file_internal_name2native_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(prim_file_internal_name2native_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_prim_file_internal_name2native_1, .-nbif_prim_file_internal_name2native_1
	.type	nbif_prim_file_internal_name2native_1, %function
#endif

#ifndef HAVE_nbif_prim_file_internal_native2name_1
#define HAVE_nbif_prim_file_internal_native2name_1
	.global	nbif_prim_file_internal_native2name_1
nbif_prim_file_internal_native2name_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(prim_file_internal_native2name_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_prim_file_internal_native2name_1, .-nbif_prim_file_internal_native2name_1
	.type	nbif_prim_file_internal_native2name_1, %function
#endif

#ifndef HAVE_nbif_prim_file_internal_normalize_utf8_1
#define HAVE_nbif_prim_file_internal_normalize_utf8_1
	.global	nbif_prim_file_internal_normalize_utf8_1
nbif_prim_file_internal_normalize_utf8_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(prim_file_internal_normalize_utf8_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_prim_file_internal_normalize_utf8_1, .-nbif_prim_file_internal_normalize_utf8_1
	.type	nbif_prim_file_internal_normalize_utf8_1, %function
#endif

#ifndef HAVE_nbif_prim_file_is_translatable_1
#define HAVE_nbif_prim_file_is_translatable_1
	.global	nbif_prim_file_is_translatable_1
nbif_prim_file_is_translatable_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(prim_file_is_translatable_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_prim_file_is_translatable_1, .-nbif_prim_file_is_translatable_1
	.type	nbif_prim_file_is_translatable_1, %function
#endif

#ifndef HAVE_nbif_file_native_name_encoding_0
#define HAVE_nbif_file_native_name_encoding_0
	.global	nbif_file_native_name_encoding_0
nbif_file_native_name_encoding_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(file_native_name_encoding_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_file_native_name_encoding_0, .-nbif_file_native_name_encoding_0
	.type	nbif_file_native_name_encoding_0, %function
#endif

#ifndef HAVE_nbif_check_old_code_1
#define HAVE_nbif_check_old_code_1
	.global	nbif_check_old_code_1
nbif_check_old_code_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(check_old_code_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_check_old_code_1, .-nbif_check_old_code_1
	.type	nbif_check_old_code_1, %function
#endif

#ifndef HAVE_nbif_universaltime_to_posixtime_1
#define HAVE_nbif_universaltime_to_posixtime_1
	.global	nbif_universaltime_to_posixtime_1
nbif_universaltime_to_posixtime_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(universaltime_to_posixtime_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_universaltime_to_posixtime_1, .-nbif_universaltime_to_posixtime_1
	.type	nbif_universaltime_to_posixtime_1, %function
#endif

#ifndef HAVE_nbif_posixtime_to_universaltime_1
#define HAVE_nbif_posixtime_to_universaltime_1
	.global	nbif_posixtime_to_universaltime_1
nbif_posixtime_to_universaltime_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(posixtime_to_universaltime_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_posixtime_to_universaltime_1, .-nbif_posixtime_to_universaltime_1
	.type	nbif_posixtime_to_universaltime_1, %function
#endif

#ifndef HAVE_nbif_dt_put_tag_1
#define HAVE_nbif_dt_put_tag_1
	.global	nbif_dt_put_tag_1
nbif_dt_put_tag_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(dt_put_tag_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_dt_put_tag_1, .-nbif_dt_put_tag_1
	.type	nbif_dt_put_tag_1, %function
#endif

#ifndef HAVE_nbif_dt_get_tag_0
#define HAVE_nbif_dt_get_tag_0
	.global	nbif_dt_get_tag_0
nbif_dt_get_tag_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(dt_get_tag_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_dt_get_tag_0, .-nbif_dt_get_tag_0
	.type	nbif_dt_get_tag_0, %function
#endif

#ifndef HAVE_nbif_dt_get_tag_data_0
#define HAVE_nbif_dt_get_tag_data_0
	.global	nbif_dt_get_tag_data_0
nbif_dt_get_tag_data_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(dt_get_tag_data_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_dt_get_tag_data_0, .-nbif_dt_get_tag_data_0
	.type	nbif_dt_get_tag_data_0, %function
#endif

#ifndef HAVE_nbif_dt_spread_tag_1
#define HAVE_nbif_dt_spread_tag_1
	.global	nbif_dt_spread_tag_1
nbif_dt_spread_tag_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(dt_spread_tag_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_dt_spread_tag_1, .-nbif_dt_spread_tag_1
	.type	nbif_dt_spread_tag_1, %function
#endif

#ifndef HAVE_nbif_dt_restore_tag_1
#define HAVE_nbif_dt_restore_tag_1
	.global	nbif_dt_restore_tag_1
nbif_dt_restore_tag_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(dt_restore_tag_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_dt_restore_tag_1, .-nbif_dt_restore_tag_1
	.type	nbif_dt_restore_tag_1, %function
#endif

#ifndef HAVE_nbif_dt_prepend_vm_tag_data_1
#define HAVE_nbif_dt_prepend_vm_tag_data_1
	.global	nbif_dt_prepend_vm_tag_data_1
nbif_dt_prepend_vm_tag_data_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(dt_prepend_vm_tag_data_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_dt_prepend_vm_tag_data_1, .-nbif_dt_prepend_vm_tag_data_1
	.type	nbif_dt_prepend_vm_tag_data_1, %function
#endif

#ifndef HAVE_nbif_dt_append_vm_tag_data_1
#define HAVE_nbif_dt_append_vm_tag_data_1
	.global	nbif_dt_append_vm_tag_data_1
nbif_dt_append_vm_tag_data_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(dt_append_vm_tag_data_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_dt_append_vm_tag_data_1, .-nbif_dt_append_vm_tag_data_1
	.type	nbif_dt_append_vm_tag_data_1, %function
#endif

#ifndef HAVE_nbif_prepare_loading_2
#define HAVE_nbif_prepare_loading_2
	.global	nbif_prepare_loading_2
nbif_prepare_loading_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(prepare_loading_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_prepare_loading_2, .-nbif_prepare_loading_2
	.type	nbif_prepare_loading_2, %function
#endif

#ifndef HAVE_nbif_finish_loading_1
#define HAVE_nbif_finish_loading_1
	.global	nbif_finish_loading_1
nbif_finish_loading_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(finish_loading_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_finish_loading_1, .-nbif_finish_loading_1
	.type	nbif_finish_loading_1, %function
#endif

#ifndef HAVE_nbif_insert_element_3
#define HAVE_nbif_insert_element_3
	.global	nbif_insert_element_3
nbif_insert_element_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(insert_element_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_insert_element_3, .-nbif_insert_element_3
	.type	nbif_insert_element_3, %function
#endif

#ifndef HAVE_nbif_delete_element_2
#define HAVE_nbif_delete_element_2
	.global	nbif_delete_element_2
nbif_delete_element_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(delete_element_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_delete_element_2, .-nbif_delete_element_2
	.type	nbif_delete_element_2, %function
#endif

#ifndef HAVE_nbif_binary_to_integer_1
#define HAVE_nbif_binary_to_integer_1
	.global	nbif_binary_to_integer_1
nbif_binary_to_integer_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_to_integer_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_to_integer_1, .-nbif_binary_to_integer_1
	.type	nbif_binary_to_integer_1, %function
#endif

#ifndef HAVE_nbif_binary_to_integer_2
#define HAVE_nbif_binary_to_integer_2
	.global	nbif_binary_to_integer_2
nbif_binary_to_integer_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_to_integer_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_binary_to_integer_2, .-nbif_binary_to_integer_2
	.type	nbif_binary_to_integer_2, %function
#endif

#ifndef HAVE_nbif_integer_to_binary_1
#define HAVE_nbif_integer_to_binary_1
	.global	nbif_integer_to_binary_1
nbif_integer_to_binary_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(integer_to_binary_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_integer_to_binary_1, .-nbif_integer_to_binary_1
	.type	nbif_integer_to_binary_1, %function
#endif

#ifndef HAVE_nbif_list_to_integer_2
#define HAVE_nbif_list_to_integer_2
	.global	nbif_list_to_integer_2
nbif_list_to_integer_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(list_to_integer_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_list_to_integer_2, .-nbif_list_to_integer_2
	.type	nbif_list_to_integer_2, %function
#endif

#ifndef HAVE_nbif_float_to_binary_1
#define HAVE_nbif_float_to_binary_1
	.global	nbif_float_to_binary_1
nbif_float_to_binary_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(float_to_binary_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_float_to_binary_1, .-nbif_float_to_binary_1
	.type	nbif_float_to_binary_1, %function
#endif

#ifndef HAVE_nbif_float_to_binary_2
#define HAVE_nbif_float_to_binary_2
	.global	nbif_float_to_binary_2
nbif_float_to_binary_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(float_to_binary_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_float_to_binary_2, .-nbif_float_to_binary_2
	.type	nbif_float_to_binary_2, %function
#endif

#ifndef HAVE_nbif_binary_to_float_1
#define HAVE_nbif_binary_to_float_1
	.global	nbif_binary_to_float_1
nbif_binary_to_float_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(binary_to_float_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_binary_to_float_1, .-nbif_binary_to_float_1
	.type	nbif_binary_to_float_1, %function
#endif

#ifndef HAVE_nbif_io_printable_range_0
#define HAVE_nbif_io_printable_range_0
	.global	nbif_io_printable_range_0
nbif_io_printable_range_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(io_printable_range_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_io_printable_range_0, .-nbif_io_printable_range_0
	.type	nbif_io_printable_range_0, %function
#endif

#ifndef HAVE_nbif_os_unsetenv_1
#define HAVE_nbif_os_unsetenv_1
	.global	nbif_os_unsetenv_1
nbif_os_unsetenv_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(os_unsetenv_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_os_unsetenv_1, .-nbif_os_unsetenv_1
	.type	nbif_os_unsetenv_1, %function
#endif

#ifndef HAVE_nbif_re_inspect_2
#define HAVE_nbif_re_inspect_2
	.global	nbif_re_inspect_2
nbif_re_inspect_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(re_inspect_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_re_inspect_2, .-nbif_re_inspect_2
	.type	nbif_re_inspect_2, %function
#endif

#ifndef HAVE_nbif_is_map_1
#define HAVE_nbif_is_map_1
	.global	nbif_is_map_1
nbif_is_map_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(is_map_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_is_map_1, .-nbif_is_map_1
	.type	nbif_is_map_1, %function
#endif

#ifndef HAVE_nbif_map_size_1
#define HAVE_nbif_map_size_1
	.global	nbif_map_size_1
nbif_map_size_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(map_size_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_map_size_1, .-nbif_map_size_1
	.type	nbif_map_size_1, %function
#endif

#ifndef HAVE_nbif_maps_to_list_1
#define HAVE_nbif_maps_to_list_1
	.global	nbif_maps_to_list_1
nbif_maps_to_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(maps_to_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_maps_to_list_1, .-nbif_maps_to_list_1
	.type	nbif_maps_to_list_1, %function
#endif

#ifndef HAVE_nbif_maps_find_2
#define HAVE_nbif_maps_find_2
	.global	nbif_maps_find_2
nbif_maps_find_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(maps_find_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_maps_find_2, .-nbif_maps_find_2
	.type	nbif_maps_find_2, %function
#endif

#ifndef HAVE_nbif_maps_get_2
#define HAVE_nbif_maps_get_2
	.global	nbif_maps_get_2
nbif_maps_get_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(maps_get_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_maps_get_2, .-nbif_maps_get_2
	.type	nbif_maps_get_2, %function
#endif

#ifndef HAVE_nbif_maps_from_list_1
#define HAVE_nbif_maps_from_list_1
	.global	nbif_maps_from_list_1
nbif_maps_from_list_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(maps_from_list_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_maps_from_list_1, .-nbif_maps_from_list_1
	.type	nbif_maps_from_list_1, %function
#endif

#ifndef HAVE_nbif_maps_is_key_2
#define HAVE_nbif_maps_is_key_2
	.global	nbif_maps_is_key_2
nbif_maps_is_key_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(maps_is_key_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_maps_is_key_2, .-nbif_maps_is_key_2
	.type	nbif_maps_is_key_2, %function
#endif

#ifndef HAVE_nbif_maps_keys_1
#define HAVE_nbif_maps_keys_1
	.global	nbif_maps_keys_1
nbif_maps_keys_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(maps_keys_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_maps_keys_1, .-nbif_maps_keys_1
	.type	nbif_maps_keys_1, %function
#endif

#ifndef HAVE_nbif_maps_merge_2
#define HAVE_nbif_maps_merge_2
	.global	nbif_maps_merge_2
nbif_maps_merge_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(maps_merge_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_maps_merge_2, .-nbif_maps_merge_2
	.type	nbif_maps_merge_2, %function
#endif

#ifndef HAVE_nbif_maps_new_0
#define HAVE_nbif_maps_new_0
	.global	nbif_maps_new_0
nbif_maps_new_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(maps_new_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_maps_new_0, .-nbif_maps_new_0
	.type	nbif_maps_new_0, %function
#endif

#ifndef HAVE_nbif_maps_put_3
#define HAVE_nbif_maps_put_3
	.global	nbif_maps_put_3
nbif_maps_put_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(maps_put_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_maps_put_3, .-nbif_maps_put_3
	.type	nbif_maps_put_3, %function
#endif

#ifndef HAVE_nbif_maps_remove_2
#define HAVE_nbif_maps_remove_2
	.global	nbif_maps_remove_2
nbif_maps_remove_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(maps_remove_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_maps_remove_2, .-nbif_maps_remove_2
	.type	nbif_maps_remove_2, %function
#endif

#ifndef HAVE_nbif_maps_update_3
#define HAVE_nbif_maps_update_3
	.global	nbif_maps_update_3
nbif_maps_update_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(maps_update_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_maps_update_3, .-nbif_maps_update_3
	.type	nbif_maps_update_3, %function
#endif

#ifndef HAVE_nbif_maps_values_1
#define HAVE_nbif_maps_values_1
	.global	nbif_maps_values_1
nbif_maps_values_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(maps_values_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_maps_values_1, .-nbif_maps_values_1
	.type	nbif_maps_values_1, %function
#endif

#ifndef HAVE_nbif_erts_internal_cmp_term_2
#define HAVE_nbif_erts_internal_cmp_term_2
	.global	nbif_erts_internal_cmp_term_2
nbif_erts_internal_cmp_term_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(erts_internal_cmp_term_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_erts_internal_cmp_term_2, .-nbif_erts_internal_cmp_term_2
	.type	nbif_erts_internal_cmp_term_2, %function
#endif

#ifndef HAVE_nbif_fun_info_mfa_1
#define HAVE_nbif_fun_info_mfa_1
	.global	nbif_fun_info_mfa_1
nbif_fun_info_mfa_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(fun_info_mfa_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_fun_info_mfa_1, .-nbif_fun_info_mfa_1
	.type	nbif_fun_info_mfa_1, %function
#endif

#ifndef HAVE_nbif_hash_2
#define HAVE_nbif_hash_2
	.global	nbif_hash_2
nbif_hash_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hash_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hash_2, .-nbif_hash_2
	.type	nbif_hash_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_write_u8_2
#define HAVE_nbif_hipe_bifs_write_u8_2
	.global	nbif_hipe_bifs_write_u8_2
nbif_hipe_bifs_write_u8_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_write_u8_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_write_u8_2, .-nbif_hipe_bifs_write_u8_2
	.type	nbif_hipe_bifs_write_u8_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_write_u32_2
#define HAVE_nbif_hipe_bifs_write_u32_2
	.global	nbif_hipe_bifs_write_u32_2
nbif_hipe_bifs_write_u32_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_write_u32_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_write_u32_2, .-nbif_hipe_bifs_write_u32_2
	.type	nbif_hipe_bifs_write_u32_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_bytearray_2
#define HAVE_nbif_hipe_bifs_bytearray_2
	.global	nbif_hipe_bifs_bytearray_2
nbif_hipe_bifs_bytearray_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_bytearray_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_bytearray_2, .-nbif_hipe_bifs_bytearray_2
	.type	nbif_hipe_bifs_bytearray_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_bytearray_sub_2
#define HAVE_nbif_hipe_bifs_bytearray_sub_2
	.global	nbif_hipe_bifs_bytearray_sub_2
nbif_hipe_bifs_bytearray_sub_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_bytearray_sub_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_bytearray_sub_2, .-nbif_hipe_bifs_bytearray_sub_2
	.type	nbif_hipe_bifs_bytearray_sub_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_bytearray_update_3
#define HAVE_nbif_hipe_bifs_bytearray_update_3
	.global	nbif_hipe_bifs_bytearray_update_3
nbif_hipe_bifs_bytearray_update_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_bytearray_update_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_bytearray_update_3, .-nbif_hipe_bifs_bytearray_update_3
	.type	nbif_hipe_bifs_bytearray_update_3, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_bitarray_2
#define HAVE_nbif_hipe_bifs_bitarray_2
	.global	nbif_hipe_bifs_bitarray_2
nbif_hipe_bifs_bitarray_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_bitarray_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_bitarray_2, .-nbif_hipe_bifs_bitarray_2
	.type	nbif_hipe_bifs_bitarray_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_bitarray_sub_2
#define HAVE_nbif_hipe_bifs_bitarray_sub_2
	.global	nbif_hipe_bifs_bitarray_sub_2
nbif_hipe_bifs_bitarray_sub_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_bitarray_sub_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_bitarray_sub_2, .-nbif_hipe_bifs_bitarray_sub_2
	.type	nbif_hipe_bifs_bitarray_sub_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_bitarray_update_3
#define HAVE_nbif_hipe_bifs_bitarray_update_3
	.global	nbif_hipe_bifs_bitarray_update_3
nbif_hipe_bifs_bitarray_update_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_bitarray_update_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_bitarray_update_3, .-nbif_hipe_bifs_bitarray_update_3
	.type	nbif_hipe_bifs_bitarray_update_3, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_array_2
#define HAVE_nbif_hipe_bifs_array_2
	.global	nbif_hipe_bifs_array_2
nbif_hipe_bifs_array_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_array_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_array_2, .-nbif_hipe_bifs_array_2
	.type	nbif_hipe_bifs_array_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_array_length_1
#define HAVE_nbif_hipe_bifs_array_length_1
	.global	nbif_hipe_bifs_array_length_1
nbif_hipe_bifs_array_length_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_array_length_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_array_length_1, .-nbif_hipe_bifs_array_length_1
	.type	nbif_hipe_bifs_array_length_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_array_sub_2
#define HAVE_nbif_hipe_bifs_array_sub_2
	.global	nbif_hipe_bifs_array_sub_2
nbif_hipe_bifs_array_sub_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_array_sub_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_array_sub_2, .-nbif_hipe_bifs_array_sub_2
	.type	nbif_hipe_bifs_array_sub_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_array_update_3
#define HAVE_nbif_hipe_bifs_array_update_3
	.global	nbif_hipe_bifs_array_update_3
nbif_hipe_bifs_array_update_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_array_update_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_array_update_3, .-nbif_hipe_bifs_array_update_3
	.type	nbif_hipe_bifs_array_update_3, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_ref_1
#define HAVE_nbif_hipe_bifs_ref_1
	.global	nbif_hipe_bifs_ref_1
nbif_hipe_bifs_ref_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_ref_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_ref_1, .-nbif_hipe_bifs_ref_1
	.type	nbif_hipe_bifs_ref_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_ref_get_1
#define HAVE_nbif_hipe_bifs_ref_get_1
	.global	nbif_hipe_bifs_ref_get_1
nbif_hipe_bifs_ref_get_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_ref_get_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_ref_get_1, .-nbif_hipe_bifs_ref_get_1
	.type	nbif_hipe_bifs_ref_get_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_ref_set_2
#define HAVE_nbif_hipe_bifs_ref_set_2
	.global	nbif_hipe_bifs_ref_set_2
nbif_hipe_bifs_ref_set_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_ref_set_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_ref_set_2, .-nbif_hipe_bifs_ref_set_2
	.type	nbif_hipe_bifs_ref_set_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_enter_code_2
#define HAVE_nbif_hipe_bifs_enter_code_2
	.global	nbif_hipe_bifs_enter_code_2
nbif_hipe_bifs_enter_code_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_enter_code_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_enter_code_2, .-nbif_hipe_bifs_enter_code_2
	.type	nbif_hipe_bifs_enter_code_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_alloc_data_2
#define HAVE_nbif_hipe_bifs_alloc_data_2
	.global	nbif_hipe_bifs_alloc_data_2
nbif_hipe_bifs_alloc_data_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_alloc_data_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_alloc_data_2, .-nbif_hipe_bifs_alloc_data_2
	.type	nbif_hipe_bifs_alloc_data_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_constants_size_0
#define HAVE_nbif_hipe_bifs_constants_size_0
	.global	nbif_hipe_bifs_constants_size_0
nbif_hipe_bifs_constants_size_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_constants_size_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_constants_size_0, .-nbif_hipe_bifs_constants_size_0
	.type	nbif_hipe_bifs_constants_size_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_merge_term_1
#define HAVE_nbif_hipe_bifs_merge_term_1
	.global	nbif_hipe_bifs_merge_term_1
nbif_hipe_bifs_merge_term_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_merge_term_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_merge_term_1, .-nbif_hipe_bifs_merge_term_1
	.type	nbif_hipe_bifs_merge_term_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_fun_to_address_1
#define HAVE_nbif_hipe_bifs_fun_to_address_1
	.global	nbif_hipe_bifs_fun_to_address_1
nbif_hipe_bifs_fun_to_address_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_fun_to_address_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_fun_to_address_1, .-nbif_hipe_bifs_fun_to_address_1
	.type	nbif_hipe_bifs_fun_to_address_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_set_native_address_3
#define HAVE_nbif_hipe_bifs_set_native_address_3
	.global	nbif_hipe_bifs_set_native_address_3
nbif_hipe_bifs_set_native_address_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_set_native_address_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_set_native_address_3, .-nbif_hipe_bifs_set_native_address_3
	.type	nbif_hipe_bifs_set_native_address_3, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_set_funinfo_native_address_3
#define HAVE_nbif_hipe_bifs_set_funinfo_native_address_3
	.global	nbif_hipe_bifs_set_funinfo_native_address_3
nbif_hipe_bifs_set_funinfo_native_address_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_set_funinfo_native_address_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_set_funinfo_native_address_3, .-nbif_hipe_bifs_set_funinfo_native_address_3
	.type	nbif_hipe_bifs_set_funinfo_native_address_3, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_invalidate_funinfo_native_addresses_1
#define HAVE_nbif_hipe_bifs_invalidate_funinfo_native_addresses_1
	.global	nbif_hipe_bifs_invalidate_funinfo_native_addresses_1
nbif_hipe_bifs_invalidate_funinfo_native_addresses_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_invalidate_funinfo_native_addresses_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_invalidate_funinfo_native_addresses_1, .-nbif_hipe_bifs_invalidate_funinfo_native_addresses_1
	.type	nbif_hipe_bifs_invalidate_funinfo_native_addresses_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_update_code_size_3
#define HAVE_nbif_hipe_bifs_update_code_size_3
	.global	nbif_hipe_bifs_update_code_size_3
nbif_hipe_bifs_update_code_size_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_update_code_size_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_update_code_size_3, .-nbif_hipe_bifs_update_code_size_3
	.type	nbif_hipe_bifs_update_code_size_3, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_code_size_1
#define HAVE_nbif_hipe_bifs_code_size_1
	.global	nbif_hipe_bifs_code_size_1
nbif_hipe_bifs_code_size_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_code_size_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_code_size_1, .-nbif_hipe_bifs_code_size_1
	.type	nbif_hipe_bifs_code_size_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_enter_sdesc_1
#define HAVE_nbif_hipe_bifs_enter_sdesc_1
	.global	nbif_hipe_bifs_enter_sdesc_1
nbif_hipe_bifs_enter_sdesc_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_enter_sdesc_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_enter_sdesc_1, .-nbif_hipe_bifs_enter_sdesc_1
	.type	nbif_hipe_bifs_enter_sdesc_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_bif_address_3
#define HAVE_nbif_hipe_bifs_bif_address_3
	.global	nbif_hipe_bifs_bif_address_3
nbif_hipe_bifs_bif_address_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_bif_address_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_bif_address_3, .-nbif_hipe_bifs_bif_address_3
	.type	nbif_hipe_bifs_bif_address_3, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_primop_address_1
#define HAVE_nbif_hipe_bifs_primop_address_1
	.global	nbif_hipe_bifs_primop_address_1
nbif_hipe_bifs_primop_address_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_primop_address_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_primop_address_1, .-nbif_hipe_bifs_primop_address_1
	.type	nbif_hipe_bifs_primop_address_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_atom_to_word_1
#define HAVE_nbif_hipe_bifs_atom_to_word_1
	.global	nbif_hipe_bifs_atom_to_word_1
nbif_hipe_bifs_atom_to_word_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_atom_to_word_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_atom_to_word_1, .-nbif_hipe_bifs_atom_to_word_1
	.type	nbif_hipe_bifs_atom_to_word_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_term_to_word_1
#define HAVE_nbif_hipe_bifs_term_to_word_1
	.global	nbif_hipe_bifs_term_to_word_1
nbif_hipe_bifs_term_to_word_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_term_to_word_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_term_to_word_1, .-nbif_hipe_bifs_term_to_word_1
	.type	nbif_hipe_bifs_term_to_word_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_get_fe_2
#define HAVE_nbif_hipe_bifs_get_fe_2
	.global	nbif_hipe_bifs_get_fe_2
nbif_hipe_bifs_get_fe_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_get_fe_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_get_fe_2, .-nbif_hipe_bifs_get_fe_2
	.type	nbif_hipe_bifs_get_fe_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_set_native_address_in_fe_2
#define HAVE_nbif_hipe_bifs_set_native_address_in_fe_2
	.global	nbif_hipe_bifs_set_native_address_in_fe_2
nbif_hipe_bifs_set_native_address_in_fe_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_set_native_address_in_fe_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_set_native_address_in_fe_2, .-nbif_hipe_bifs_set_native_address_in_fe_2
	.type	nbif_hipe_bifs_set_native_address_in_fe_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_find_na_or_make_stub_2
#define HAVE_nbif_hipe_bifs_find_na_or_make_stub_2
	.global	nbif_hipe_bifs_find_na_or_make_stub_2
nbif_hipe_bifs_find_na_or_make_stub_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_find_na_or_make_stub_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_find_na_or_make_stub_2, .-nbif_hipe_bifs_find_na_or_make_stub_2
	.type	nbif_hipe_bifs_find_na_or_make_stub_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_check_crc_1
#define HAVE_nbif_hipe_bifs_check_crc_1
	.global	nbif_hipe_bifs_check_crc_1
nbif_hipe_bifs_check_crc_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_check_crc_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_check_crc_1, .-nbif_hipe_bifs_check_crc_1
	.type	nbif_hipe_bifs_check_crc_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_system_crc_1
#define HAVE_nbif_hipe_bifs_system_crc_1
	.global	nbif_hipe_bifs_system_crc_1
nbif_hipe_bifs_system_crc_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_system_crc_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_system_crc_1, .-nbif_hipe_bifs_system_crc_1
	.type	nbif_hipe_bifs_system_crc_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_get_rts_param_1
#define HAVE_nbif_hipe_bifs_get_rts_param_1
	.global	nbif_hipe_bifs_get_rts_param_1
nbif_hipe_bifs_get_rts_param_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_get_rts_param_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_get_rts_param_1, .-nbif_hipe_bifs_get_rts_param_1
	.type	nbif_hipe_bifs_get_rts_param_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_patch_insn_3
#define HAVE_nbif_hipe_bifs_patch_insn_3
	.global	nbif_hipe_bifs_patch_insn_3
nbif_hipe_bifs_patch_insn_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_patch_insn_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_patch_insn_3, .-nbif_hipe_bifs_patch_insn_3
	.type	nbif_hipe_bifs_patch_insn_3, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_patch_call_3
#define HAVE_nbif_hipe_bifs_patch_call_3
	.global	nbif_hipe_bifs_patch_call_3
nbif_hipe_bifs_patch_call_3:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2
	# mov	r3, r3

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	str	r3, [r0, #P_ARG2]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_patch_call_3)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_3_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_3_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_patch_call_3, .-nbif_hipe_bifs_patch_call_3
	.type	nbif_hipe_bifs_patch_call_3, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_add_ref_2
#define HAVE_nbif_hipe_bifs_add_ref_2
	.global	nbif_hipe_bifs_add_ref_2
nbif_hipe_bifs_add_ref_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_add_ref_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_add_ref_2, .-nbif_hipe_bifs_add_ref_2
	.type	nbif_hipe_bifs_add_ref_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_mark_referred_from_1
#define HAVE_nbif_hipe_bifs_mark_referred_from_1
	.global	nbif_hipe_bifs_mark_referred_from_1
nbif_hipe_bifs_mark_referred_from_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_mark_referred_from_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_mark_referred_from_1, .-nbif_hipe_bifs_mark_referred_from_1
	.type	nbif_hipe_bifs_mark_referred_from_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_remove_refs_from_1
#define HAVE_nbif_hipe_bifs_remove_refs_from_1
	.global	nbif_hipe_bifs_remove_refs_from_1
nbif_hipe_bifs_remove_refs_from_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_remove_refs_from_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_remove_refs_from_1, .-nbif_hipe_bifs_remove_refs_from_1
	.type	nbif_hipe_bifs_remove_refs_from_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_redirect_referred_from_1
#define HAVE_nbif_hipe_bifs_redirect_referred_from_1
	.global	nbif_hipe_bifs_redirect_referred_from_1
nbif_hipe_bifs_redirect_referred_from_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_redirect_referred_from_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_redirect_referred_from_1, .-nbif_hipe_bifs_redirect_referred_from_1
	.type	nbif_hipe_bifs_redirect_referred_from_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_call_count_on_1
#define HAVE_nbif_hipe_bifs_call_count_on_1
	.global	nbif_hipe_bifs_call_count_on_1
nbif_hipe_bifs_call_count_on_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_call_count_on_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_call_count_on_1, .-nbif_hipe_bifs_call_count_on_1
	.type	nbif_hipe_bifs_call_count_on_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_call_count_off_1
#define HAVE_nbif_hipe_bifs_call_count_off_1
	.global	nbif_hipe_bifs_call_count_off_1
nbif_hipe_bifs_call_count_off_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_call_count_off_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_call_count_off_1, .-nbif_hipe_bifs_call_count_off_1
	.type	nbif_hipe_bifs_call_count_off_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_call_count_get_1
#define HAVE_nbif_hipe_bifs_call_count_get_1
	.global	nbif_hipe_bifs_call_count_get_1
nbif_hipe_bifs_call_count_get_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_call_count_get_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_call_count_get_1, .-nbif_hipe_bifs_call_count_get_1
	.type	nbif_hipe_bifs_call_count_get_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_call_count_clear_1
#define HAVE_nbif_hipe_bifs_call_count_clear_1
	.global	nbif_hipe_bifs_call_count_clear_1
nbif_hipe_bifs_call_count_clear_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_call_count_clear_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_call_count_clear_1, .-nbif_hipe_bifs_call_count_clear_1
	.type	nbif_hipe_bifs_call_count_clear_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_trap_count_get_0
#define HAVE_nbif_hipe_bifs_trap_count_get_0
	.global	nbif_hipe_bifs_trap_count_get_0
nbif_hipe_bifs_trap_count_get_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_trap_count_get_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_trap_count_get_0, .-nbif_hipe_bifs_trap_count_get_0
	.type	nbif_hipe_bifs_trap_count_get_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_trap_count_clear_0
#define HAVE_nbif_hipe_bifs_trap_count_clear_0
	.global	nbif_hipe_bifs_trap_count_clear_0
nbif_hipe_bifs_trap_count_clear_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_trap_count_clear_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_trap_count_clear_0, .-nbif_hipe_bifs_trap_count_clear_0
	.type	nbif_hipe_bifs_trap_count_clear_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_process_info_0
#define HAVE_nbif_hipe_bifs_process_info_0
	.global	nbif_hipe_bifs_process_info_0
nbif_hipe_bifs_process_info_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_process_info_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_process_info_0, .-nbif_hipe_bifs_process_info_0
	.type	nbif_hipe_bifs_process_info_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_process_info_clear_0
#define HAVE_nbif_hipe_bifs_process_info_clear_0
	.global	nbif_hipe_bifs_process_info_clear_0
nbif_hipe_bifs_process_info_clear_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_process_info_clear_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_process_info_clear_0, .-nbif_hipe_bifs_process_info_clear_0
	.type	nbif_hipe_bifs_process_info_clear_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_message_info_0
#define HAVE_nbif_hipe_bifs_message_info_0
	.global	nbif_hipe_bifs_message_info_0
nbif_hipe_bifs_message_info_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_message_info_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_message_info_0, .-nbif_hipe_bifs_message_info_0
	.type	nbif_hipe_bifs_message_info_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_message_info_clear_0
#define HAVE_nbif_hipe_bifs_message_info_clear_0
	.global	nbif_hipe_bifs_message_info_clear_0
nbif_hipe_bifs_message_info_clear_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_message_info_clear_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_message_info_clear_0, .-nbif_hipe_bifs_message_info_clear_0
	.type	nbif_hipe_bifs_message_info_clear_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_message_sizes_0
#define HAVE_nbif_hipe_bifs_message_sizes_0
	.global	nbif_hipe_bifs_message_sizes_0
nbif_hipe_bifs_message_sizes_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_message_sizes_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_message_sizes_0, .-nbif_hipe_bifs_message_sizes_0
	.type	nbif_hipe_bifs_message_sizes_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_gc_info_0
#define HAVE_nbif_hipe_bifs_gc_info_0
	.global	nbif_hipe_bifs_gc_info_0
nbif_hipe_bifs_gc_info_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_gc_info_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_gc_info_0, .-nbif_hipe_bifs_gc_info_0
	.type	nbif_hipe_bifs_gc_info_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_shared_gc_info_0
#define HAVE_nbif_hipe_bifs_shared_gc_info_0
	.global	nbif_hipe_bifs_shared_gc_info_0
nbif_hipe_bifs_shared_gc_info_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_shared_gc_info_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_shared_gc_info_0, .-nbif_hipe_bifs_shared_gc_info_0
	.type	nbif_hipe_bifs_shared_gc_info_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_incremental_gc_info_0
#define HAVE_nbif_hipe_bifs_incremental_gc_info_0
	.global	nbif_hipe_bifs_incremental_gc_info_0
nbif_hipe_bifs_incremental_gc_info_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_incremental_gc_info_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_incremental_gc_info_0, .-nbif_hipe_bifs_incremental_gc_info_0
	.type	nbif_hipe_bifs_incremental_gc_info_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_gc_info_clear_0
#define HAVE_nbif_hipe_bifs_gc_info_clear_0
	.global	nbif_hipe_bifs_gc_info_clear_0
nbif_hipe_bifs_gc_info_clear_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_gc_info_clear_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_gc_info_clear_0, .-nbif_hipe_bifs_gc_info_clear_0
	.type	nbif_hipe_bifs_gc_info_clear_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_pause_times_0
#define HAVE_nbif_hipe_bifs_pause_times_0
	.global	nbif_hipe_bifs_pause_times_0
nbif_hipe_bifs_pause_times_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_pause_times_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_pause_times_0, .-nbif_hipe_bifs_pause_times_0
	.type	nbif_hipe_bifs_pause_times_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_system_timer_0
#define HAVE_nbif_hipe_bifs_system_timer_0
	.global	nbif_hipe_bifs_system_timer_0
nbif_hipe_bifs_system_timer_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_system_timer_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_system_timer_0, .-nbif_hipe_bifs_system_timer_0
	.type	nbif_hipe_bifs_system_timer_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_system_timer_clear_0
#define HAVE_nbif_hipe_bifs_system_timer_clear_0
	.global	nbif_hipe_bifs_system_timer_clear_0
nbif_hipe_bifs_system_timer_clear_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_system_timer_clear_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_system_timer_clear_0, .-nbif_hipe_bifs_system_timer_clear_0
	.type	nbif_hipe_bifs_system_timer_clear_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_send_timer_0
#define HAVE_nbif_hipe_bifs_send_timer_0
	.global	nbif_hipe_bifs_send_timer_0
nbif_hipe_bifs_send_timer_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_send_timer_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_send_timer_0, .-nbif_hipe_bifs_send_timer_0
	.type	nbif_hipe_bifs_send_timer_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_send_timer_clear_0
#define HAVE_nbif_hipe_bifs_send_timer_clear_0
	.global	nbif_hipe_bifs_send_timer_clear_0
nbif_hipe_bifs_send_timer_clear_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_send_timer_clear_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_send_timer_clear_0, .-nbif_hipe_bifs_send_timer_clear_0
	.type	nbif_hipe_bifs_send_timer_clear_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_gc_timer_0
#define HAVE_nbif_hipe_bifs_gc_timer_0
	.global	nbif_hipe_bifs_gc_timer_0
nbif_hipe_bifs_gc_timer_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_gc_timer_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_gc_timer_0, .-nbif_hipe_bifs_gc_timer_0
	.type	nbif_hipe_bifs_gc_timer_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_shared_gc_timer_0
#define HAVE_nbif_hipe_bifs_shared_gc_timer_0
	.global	nbif_hipe_bifs_shared_gc_timer_0
nbif_hipe_bifs_shared_gc_timer_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_shared_gc_timer_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_shared_gc_timer_0, .-nbif_hipe_bifs_shared_gc_timer_0
	.type	nbif_hipe_bifs_shared_gc_timer_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_gc_timer_clear_0
#define HAVE_nbif_hipe_bifs_gc_timer_clear_0
	.global	nbif_hipe_bifs_gc_timer_clear_0
nbif_hipe_bifs_gc_timer_clear_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_gc_timer_clear_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_gc_timer_clear_0, .-nbif_hipe_bifs_gc_timer_clear_0
	.type	nbif_hipe_bifs_gc_timer_clear_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_misc_timer_0
#define HAVE_nbif_hipe_bifs_misc_timer_0
	.global	nbif_hipe_bifs_misc_timer_0
nbif_hipe_bifs_misc_timer_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_misc_timer_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_misc_timer_0, .-nbif_hipe_bifs_misc_timer_0
	.type	nbif_hipe_bifs_misc_timer_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_misc_timer_clear_0
#define HAVE_nbif_hipe_bifs_misc_timer_clear_0
	.global	nbif_hipe_bifs_misc_timer_clear_0
nbif_hipe_bifs_misc_timer_clear_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_misc_timer_clear_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_misc_timer_clear_0, .-nbif_hipe_bifs_misc_timer_clear_0
	.type	nbif_hipe_bifs_misc_timer_clear_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_get_hrvtime_0
#define HAVE_nbif_hipe_bifs_get_hrvtime_0
	.global	nbif_hipe_bifs_get_hrvtime_0
nbif_hipe_bifs_get_hrvtime_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_get_hrvtime_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_get_hrvtime_0, .-nbif_hipe_bifs_get_hrvtime_0
	.type	nbif_hipe_bifs_get_hrvtime_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_stop_hrvtime_0
#define HAVE_nbif_hipe_bifs_stop_hrvtime_0
	.global	nbif_hipe_bifs_stop_hrvtime_0
nbif_hipe_bifs_stop_hrvtime_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_stop_hrvtime_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_stop_hrvtime_0, .-nbif_hipe_bifs_stop_hrvtime_0
	.type	nbif_hipe_bifs_stop_hrvtime_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_show_estack_1
#define HAVE_nbif_hipe_bifs_show_estack_1
	.global	nbif_hipe_bifs_show_estack_1
nbif_hipe_bifs_show_estack_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_show_estack_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_show_estack_1, .-nbif_hipe_bifs_show_estack_1
	.type	nbif_hipe_bifs_show_estack_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_show_heap_1
#define HAVE_nbif_hipe_bifs_show_heap_1
	.global	nbif_hipe_bifs_show_heap_1
nbif_hipe_bifs_show_heap_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_show_heap_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_show_heap_1, .-nbif_hipe_bifs_show_heap_1
	.type	nbif_hipe_bifs_show_heap_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_show_nstack_1
#define HAVE_nbif_hipe_bifs_show_nstack_1
	.global	nbif_hipe_bifs_show_nstack_1
nbif_hipe_bifs_show_nstack_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_show_nstack_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_show_nstack_1, .-nbif_hipe_bifs_show_nstack_1
	.type	nbif_hipe_bifs_show_nstack_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_nstack_used_size_0
#define HAVE_nbif_hipe_bifs_nstack_used_size_0
	.global	nbif_hipe_bifs_nstack_used_size_0
nbif_hipe_bifs_nstack_used_size_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_nstack_used_size_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_nstack_used_size_0, .-nbif_hipe_bifs_nstack_used_size_0
	.type	nbif_hipe_bifs_nstack_used_size_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_show_pcb_1
#define HAVE_nbif_hipe_bifs_show_pcb_1
	.global	nbif_hipe_bifs_show_pcb_1
nbif_hipe_bifs_show_pcb_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_show_pcb_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_show_pcb_1, .-nbif_hipe_bifs_show_pcb_1
	.type	nbif_hipe_bifs_show_pcb_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_show_term_1
#define HAVE_nbif_hipe_bifs_show_term_1
	.global	nbif_hipe_bifs_show_term_1
nbif_hipe_bifs_show_term_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_show_term_1)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_1_simple_exception
	mov pc, TEMP_LR
	.ltorg		/* needed by LDR in debug version of `CALL_BIF' */
	.size	nbif_hipe_bifs_show_term_1, .-nbif_hipe_bifs_show_term_1
	.type	nbif_hipe_bifs_show_term_1, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_in_native_0
#define HAVE_nbif_hipe_bifs_in_native_0
	.global	nbif_hipe_bifs_in_native_0
nbif_hipe_bifs_in_native_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_in_native_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_in_native_0, .-nbif_hipe_bifs_in_native_0
	.type	nbif_hipe_bifs_in_native_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_modeswitch_debug_on_0
#define HAVE_nbif_hipe_bifs_modeswitch_debug_on_0
	.global	nbif_hipe_bifs_modeswitch_debug_on_0
nbif_hipe_bifs_modeswitch_debug_on_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_modeswitch_debug_on_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_modeswitch_debug_on_0, .-nbif_hipe_bifs_modeswitch_debug_on_0
	.type	nbif_hipe_bifs_modeswitch_debug_on_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_modeswitch_debug_off_0
#define HAVE_nbif_hipe_bifs_modeswitch_debug_off_0
	.global	nbif_hipe_bifs_modeswitch_debug_off_0
nbif_hipe_bifs_modeswitch_debug_off_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_modeswitch_debug_off_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_modeswitch_debug_off_0, .-nbif_hipe_bifs_modeswitch_debug_off_0
	.type	nbif_hipe_bifs_modeswitch_debug_off_0, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_debug_native_called_2
#define HAVE_nbif_hipe_bifs_debug_native_called_2
	.global	nbif_hipe_bifs_debug_native_called_2
nbif_hipe_bifs_debug_native_called_2:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1
	# mov	r2, r2

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	str	r1, [r0, #P_ARG0]	/* Store BIF__ARGS in def_arg_reg[] */
	str	r2, [r0, #P_ARG1]
	add	r1, r0, #P_ARG0
	CALL_BIF(hipe_bifs_debug_native_called_2)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_2_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_2_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_debug_native_called_2, .-nbif_hipe_bifs_debug_native_called_2
	.type	nbif_hipe_bifs_debug_native_called_2, %function
#endif

#ifndef HAVE_nbif_hipe_bifs_llvm_fix_pinned_regs_0
#define HAVE_nbif_hipe_bifs_llvm_fix_pinned_regs_0
	.global	nbif_hipe_bifs_llvm_fix_pinned_regs_0
nbif_hipe_bifs_llvm_fix_pinned_regs_0:
	/* Set up C argument registers. */
	mov	r0, P

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	/* ignore empty BIF__ARGS */
	CALL_BIF(hipe_bifs_llvm_fix_pinned_regs_0)
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_0_gc_after_bif

	/* Restore registers. Check for exception. */
	cmp	r0, #THE_NON_VALUE
	RESTORE_CONTEXT_BIF
	beq	nbif_0_simple_exception
	mov pc, TEMP_LR
	.ltorg
	.size	nbif_hipe_bifs_llvm_fix_pinned_regs_0, .-nbif_hipe_bifs_llvm_fix_pinned_regs_0
	.type	nbif_hipe_bifs_llvm_fix_pinned_regs_0, %function
#endif


/*
 * Guard BIFs.
 * GBIF_LIST(FunctionAtom,Arity,CFun)
 */

/*
 * %CopyrightBegin%
 *
 * Copyright Ericsson AB 2001-2011. All Rights Reserved.
 *
 * The contents of this file are subject to the Erlang Public License,
 * Version 1.1, (the "License"); you may not use this file except in
 * compliance with the License. You should have received a copy of the
 * Erlang Public License along with this software. If not, it can be
 * retrieved online at http://www.erlang.org/.
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * %CopyrightEnd%
 */
/*
 * GBIF_LIST(FunctionAtom,Arity,CFun)
 * manually maintained for now -- expand when necessary
 */

#ifndef HAVE_gbif_node_1
#define HAVE_gbif_node_1
	.global	gbif_node_1
gbif_node_1:
	/* Set up C argument registers. */
	mov	r0, P
	# mov	r1, r1

	/* Save caller-save registers and call the C function. */
	SAVE_CONTEXT_BIF
	bl	node_1
	ldr r1, [P, #P_MBUF]	/* `TEST_GOT_MBUF' */
	cmp r1, #0
	blne nbif_1_gc_after_bif

	/* Restore registers. */
	RESTORE_CONTEXT_BIF
	mov pc, TEMP_LR
	.size	gbif_node_1, .-gbif_node_1
	.type	gbif_node_1, %function
#endif



#if defined(__linux__) && defined(__ELF__)
.section .note.GNU-stack,"",%progbits
#endif
